<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            admin-init.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* Main page
 -------------------------------- */
function angio_register_admin_pages() {

    add_theme_page( esc_html__( 'Angio', 'angio' ), esc_html__( 'Angio', 'angio' ), 'edit_theme_options', 'admin-welcome', 'angio_admin_page_welcome');

}
add_action('admin_menu', 'angio_register_admin_pages', 1 );


/**
 * Render admin pages header
 * @version 1.1.0
 * @return void
 */
function angio_admin_page_header() {

	$pages = array(

		array(
			'title' => esc_html__( 'Welcome', 'angio' ),
			'title_attr' => esc_html__( 'Welcome', 'angio' ),
			'id' => 'admin-welcome'
		),
		array(
			'title' => esc_html__( 'System Status', 'angio' ),
			'title_attr' => esc_html__( 'Please install Angio Toolkit plugin to activate this tab.', 'angio' ),
			'id' => 'inactive'
		),
		array(
			'title' => esc_html__( 'Theme Plugins', 'angio' ),
			'title_attr' => esc_html__( 'Theme Plugins', 'angio' ),
			'id' => 'admin-plugins'
		),
		array(
			'title' => esc_html__( 'Install Demos', 'angio' ),
			'title_attr' => esc_html__( 'Please install Angio Toolkit plugin to activate this tab.', 'angio' ),
			'id' => 'inactive'
		),
		array(
			'title' => esc_html__( 'Theme Panel', 'angio' ),
			'title_attr' => esc_html__( 'Theme Panel', 'angio' ),
			'id' => 'theme-panel'
		)

	);

	if  ( has_filter( 'rascals_admin_menu' ) ) {
		$pages = apply_filters( 'rascals_admin_menu', $pages );
	}
	
	$page_link = 'admin.php?page=';

	$theme = wp_get_theme();
	?>


	<h3 class="rascals-theme-name"><?php echo esc_html( $theme->get( 'Name' ) ); ?><span class="rascals-version"> v <?php echo esc_html( $theme->get( 'Version' ) ); ?></span></h3>

	<div class="wrap about-wrap rascals-admin-header">
	    <h2 class="nav-tab-wrapper"> 
			<?php
			foreach ( $pages as $mp_page ) {
			    $extra_classes = '';

			    $title_attr = $mp_page['title_attr']; 

		        /* Redirect */
		        if ( $mp_page['id'] === 'inactive' ) {
		        	$page_link = '#';
		        	$extra_classes .= ' inactive';
		        } else if ( strpos( $mp_page['id'], '.php' ) !== false ) {
		        	$page_link = $mp_page['id'];
		        } else {
		        	$page_link = 'admin.php?page=' . esc_attr( $mp_page['id'] );
		        }
		        
		        if ( isset( $_GET['page'] ) && ( $_GET['page'] === $mp_page['id'] ) ) { 
		        	$extra_classes .= ' nav-tab-active';
		        }

		        ?>	
		        <a href="<?php echo esc_url( $page_link ) ?>" title="<?php echo esc_attr( $title_attr ) ?>" class="nav-tab rascals-nav-tab <?php echo esc_attr( $extra_classes ); ?> "><?php echo esc_html( $mp_page['title'] ) ?></a>
		        <?php
		    }
		    ?>
		</h2>
	</div>
    <?php
	
}



/* ==================================================
  Admin Scripts 
================================================== */
function angio_admin_scripts() {

	wp_enqueue_style( 'rascals-admin-pages', get_template_directory_uri() . '/admin/assets/css/admin-page.css' );

}
add_action( 'admin_enqueue_scripts', 'angio_admin_scripts' );


/* ==================================================
  Welcome Page 
================================================== */
function angio_admin_page_welcome() {
	require_once( 'admin-welcome.php' );
}


/* ==================================================
  Plugins Page 
================================================== */
require_once( 'admin-plugins.php' );


/* ==================================================
  Theme Panel 
================================================== */
if ( ! class_exists( 'RascalsThemePanel' ) ) {

	/* Load Theme panel class */
	require_once( trailingslashit( get_template_directory() ) . 'admin/classes/class-rascals-panel.php' );

	/* Init Panel */
	require_once( trailingslashit( get_template_directory() ) . 'admin/panel-options.php' );
}
