<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            panel-options.php
 * @package angio
 * @since 1.0.0
 */

/* Exit if accessed directly */
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* Options array */
$angio_main_options = array(


	/* ==================================================
	  General Settings
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'General Settings ', 'angio' ),
		'tab_id'   => 'general_settings',
		'icon'     => 'gears'
	),
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'General Settings', 'angio' ),
			'sub_tab_id'   => 'sub-general',
		),

			// Header Style
			array(
				'name'    => esc_html__( 'Header Style', 'angio' ),
				'id'      => 'header_style',
				'type'    => 'select',
				'std'     => 'hybrid',
				'options' => array(
					array( 'name' => esc_html__( 'Classic', 'angio' ), 'value' => 'classic'),
					array( 'name' => esc_html__( 'Menu Button', 'angio' ), 'value' => 'button'),
					array( 'name' => esc_html__( 'Hybrid', 'angio' ), 'value' => 'hybrid'),

				),
				'desc' => 	esc_html__( 'Select header style.', 'angio' ) . '<br>' .
							esc_html__( 'Classic - Visible horizontal links and menu button on small screens.', 'angio' ) . '<br>'.
				  		  	esc_html__( 'Menu Button - Visible menu button on all screens, horizontal links are disabled.', 'angio' ) . '<br>'.
				  		  	esc_html__( 'Hybrid - Visible menu button on all screens and horizontal links.', 'angio' ) . '<br>'.
						  	esc_html__( 'Tip: Menu word can be replace through Loco Translate plugin or POedit app.', 'angio' ),
			),


			// Smooth Scroll
			array(
				'name' => esc_html__( 'Smooth Scrolling', 'angio' ),
				'id'   => 'smooth_scroll',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable or disable smooth vertical scrolling.', 'angio' ),
			),

			// Preloder
			array(
				'name' => esc_html__( 'Page Transition', 'angio' ),
				'id'   => 'page_transition',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable page transition effects while the page is loading.', 'angio' ) . '<br>' .
						  esc_html__( 'Tip: AJAX can be disabled in Advanced settings.', 'angio' ),
			),

			// Preloader Image
			array(
				'name'   => esc_html__( 'Preloader Image', 'angio' ),
				'id'     => 'preloader_image',
				'type'   => 'add_image',
				'source' => 'media_libary', // all, media_libary, external_link
				'desc'   => esc_html__('Set preloader image.', 'angio' ),
			),

			// Title effect
			array(

				'name'       => esc_html__( 'Title Effect', 'angio' ),
				'id'         => 'title_fx',
				'type'       => 'select',
				'multiple'   => false,
				'std'        => 'console_typer',
				'options'    => array(
					array( 'name' => esc_html__( 'None', 'angio' ), 'value' => 'none' ),
					array( 'name' => esc_html__( 'Console Typer', 'angio' ), 'value' => 'console_typer' ),
					array( 'name' => esc_html__( 'Opacity', 'angio' ), 'value' => 'opacity' ),
					array( 'name' => esc_html__( 'Slide Up', 'angio' ), 'value' => 'slideup' ),
				),
				'desc' => esc_html__( 'Select default content for new posts.', 'angio' ),
			),

			// Animate Cursor
			array(
				'name' => esc_html__( 'Cursor Effects', 'angio' ),
				'id'   => 'cursor_effects',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable cursor effects.', 'angio' ),
			),

			// Noise
			array(
				'name' => esc_html__( 'Noise Effect', 'angio' ),
				'id'   => 'noisy',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable noise effect.', 'angio' ),
			),

			// Hud
			array(
				'name' => esc_html__( 'Animate Hud', 'angio' ),
				'id'   => 'hud',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable parallax perspective effect on header and footer.', 'angio' ),
			),

			// Scroll Animations
			array(
				'name' => esc_html__( 'Scroll Animations', 'angio' ),
				'id'   => 'scrollmagic',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable scroll animations.', 'angio' ),
			),

			// BG player
			array(
				'name' => esc_html__( 'Background Player', 'angio' ),
				'id'   => 'background_player',
				'type' => 'switch_button',
				'std'  => 'off',
				'separator' => false,
				'desc' => esc_html__( 'Enable or disable background player.', 'angio' ),
			),

			// Background track
			array(
				'sub_name'   => esc_html__( 'Background Track', 'angio' ),
				'id'         => 'bg_player_track',
				'type'       => 'posts',
				'post_type'  => 'angio_tracks',
				'save_empty' => true,
				'multiple'   => false,
				'std'        => '',
				'options'    => array(
					array( 'name' => '', 'value' => 'none' )
				),
				'desc' => esc_html__( 'Select track that will be played in background. Please note, if tracklist has more tracks then the first track will be played.', 'angio' ),
				'separator' => false,
				'dependency' => array(
			        "element" => 'background_player',
			        "value" => array( 'on' )
			    )
			),

			// Custom IDS
			array(
				'sub_name'   => esc_html__( 'Custom Track ID', 'angio' ),
				'id'         => 'bg_player_ids',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Enter the track ID. By default is played first track.', 'angio' ),
				'dependency' => array(
			        "element" => 'background_player',
			        "value" => array( 'on' )
			    )
			),

			// WebGL
			array(
				'name' => esc_html__( '3D Effects (WebGL)', 'angio' ),
				'id'   => 'webgl',
				'type' => 'switch_button',
				'std'  => 'off',
				'separator' => false,
				'desc' => esc_html__( 'Enable or disable 3D effects.', 'angio' ),
			),

		array(
			'type' => 'sub_close'
		),


	array(
		'type' => 'close'
	),


	/* ==================================================
	  Sections
	================================================== */
	array(
		'type' => 'open',
		'tab_name' => esc_html__( 'Sections', 'angio' ),
		'tab_id' => 'Sections',
		'icon' => 'th-large'
	),

		/* News
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'News', 'angio' ),
			'sub_tab_id'   => 'sub-custom-news'
		),


			// Deafult post layout
			array(

				'name'       => esc_html__( 'Deafult Post Layout', 'angio' ),
				'id'         => 'post_def_content',
				'type'       => 'select',
				'multiple'   => false,
				'std'        => 'default',
				'options'    => array(
					array( 'name' => esc_html__( 'Default', 'angio' ), 'value' => 'default' ),
					array( 'name' => esc_html__( 'Fullwidth (max 1920px)', 'angio' ), 'value' => 'fullwidth' ),
					array( 'name' => esc_html__( 'Fullscreen', 'angio' ), 'value' => 'elementor' ),
				),
				'desc' => esc_html__( 'Select default content for new posts.', 'angio' ),
			),
		
			/* Default page title */
			array(
				'name'      => esc_html__( 'Default Page Title', 'angio' ),
				'id'        => 'post_def_page_title',
				'type'      => 'select',
				'std'       => 'simple',
				'options'   => array(
					array( 'name' => esc_html__( 'Disabled', 'angio' ), 'value' => 'disabled' ),
					array( 'name' => esc_html__( 'Simple (without image)', 'angio' ), 'value' => 'simple' ),
					array( 'name' => esc_html__( 'Image', 'angio' ), 'value' => 'image' ),
					array( 'name' => esc_html__( 'Fullscreen Image Parallax', 'angio' ), 'value' => 'fullscreen-parallax' ),
				),
				'separator' => true,
				'desc'      => esc_html__('Select post hero style.' , 'angio' ),
			),

			/* Share Buttons */
			array(
				'name' => esc_html__( 'Share Buttons', 'angio' ),
				'id'   => 'display_share_buttons',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Display share buttons at the bottom of the text next to tags.', 'angio' ),
			),

			/* Block */
			array(
				'name'   => esc_html__( 'Category Block', 'angio' ),
				'id'     => 'category_block',
				'type'   => 'select',
				'std'    => 'news-index',
				'options'   => array(
					array( 'name' => esc_html__( 'Big Images', 'angio' ), 'value' => 'news' ),
					array( 'name' => esc_html__( 'List', 'angio' ), 'value' => 'news2' ),
					array( 'name' => esc_html__( 'Grid', 'angio' ), 'value' => 'news3' ),
					array( 'name' => esc_html__( 'Classic List', 'angio' ), 'value' => 'news-index' ),
				),
				'desc' => esc_html__( 'Select a block to be used in the loop on categories/tags/archives/author pages.', 'angio' )
			),

			/* Sidebar position */
			array(
				'name'       => esc_html__( 'Category Sidebar Position', 'angio' ),
				'id'         => 'category_sidebar_pos',
				'type'       => 'select',
				'std'        => 'left',
				'options'	 => array(
					array( 'name' => esc_html__( 'Disabled', 'angio' ), 'value' => 'disabled' ),
					array( 'name' => esc_html__( 'Left', 'angio' ), 'value' => 'left' ),
					array( 'name' => esc_html__( 'Right', 'angio' ), 'value' => 'right' ),
				),
				'separator'  => true,
				'desc'       => esc_html__( 'Select default sidebar position on categories/tags/archives/author pages.', 'angio' ),
			),

		array(
			'type' => 'sub_close'
		),


		/* Comments
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Comments', 'angio' ),
			'sub_tab_id'   => 'sub-custom-comments'
		),
			// DISQUS
			array(
				'name' => esc_html__( 'DISQUS Comments', 'angio' ),
				'id'   => 'disqus_comments',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Enable DISQUS comments. Replace default Wordpress comments.', 'angio' ),
			),

			// Disqus ID
			array(
				'name'       => esc_html__( 'DISQUS Shortname', 'angio' ),
				'id'         => 'disqus_shortname',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Enter DISQUS Website\'s Shortname.', 'angio' ),
				'dependency' => array(
					'element' => 'disqus_comments',
					'value'   => array( 'on' )
				)
			),

		array(
			'type' => 'sub_close'
		),


		/* Events
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Events', 'angio' ),
			'sub_tab_id'   => 'sub-custom-events'
		),

			// Date in list module
			array(
				'name' => esc_html__( 'Event Date Format', 'angio' ),
				'id'   => 'event_date_format',
				'type' => 'text',
				'std'  => 'd M Y',
				'desc' => esc_html__( 'Enter your custom event date. More information: http://codex.wordpress.org/Formatting_Date_and_Time', 'angio' ),
			),


		array(
			'type' => 'sub_close'
		),

	array(
		'type' => 'close'
	),


	/* ==================================================
	  WooCommerce
	================================================== */
	array(
		'type' => 'open',
		'tab_name' => esc_html__( 'WooCommerce', 'angio' ),
		'tab_id' => 'woocommerce',
		'icon' => 'shopping-bag'
	),

		/* Shop Page
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Shop', 'angio' ),
			'sub_tab_id'   => 'sub-custom-shop'
		),	

			/* Show: Cart */
			array(
				'name' => esc_html__( 'Show Cart', 'angio' ),
				'id'   => 'wc_cart',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display cart in header section.', 'angio' ),
			),

			/* Show: Breadcrumb */
			array(
				'name' => esc_html__( 'Show Breadcrumb', 'angio' ),
				'id'   => 'wc_breadcrumb',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display breadcrumb navigation.', 'angio' ),
			),

			/* Show: Products count */
			array(
				'name' => esc_html__( 'Show Products Count', 'angio' ),
				'id'   => 'wc_products_count',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display products count on shop page.', 'angio' ),
			),

			/* Show: Ordering filter */
			array(
				'name' => esc_html__( 'Show Ordering Filter', 'angio' ),
				'id'   => 'wc_ordering_filter',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display ordering filter on shop page.', 'angio' ),
			),

			/* Show: Category filter */
			array(
				'name' => esc_html__( 'Show Category Filter', 'angio' ),
				'id'   => 'wc_category_filter',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display category filter on shop page.', 'angio' ),
			),

			/* Show: Tag filter */
			array(
				'name' => esc_html__( 'Show Tag Filter', 'angio' ),
				'id'   => 'wc_tag_filter',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Display tag filter on shop page.', 'angio' ),
			),

			/* Products Per Page */
			array(
				'name'  => esc_html__( 'Products Per Page', 'angio' ),
				'id'    => 'products_per_page',
				'type'  => 'range',
				'max'   => '999',
				'min'   => '1',
				'unit'  => 'products',
				'step'  => '1',
				'std'   => '6',
				'desc'  => esc_html__( 'Number of products per page.', 'angio' ),
			), 

			/* Products Per Row */
			array(
				'name'  => esc_html__( 'Products Per Row', 'angio' ),
				'id'    => 'products_per_row',
				'type'  => 'range',
				'max'   => '5',
				'min'   => '1',
				'unit'  => 'products',
				'step'  => '1',
				'std'   => '3',
				'desc'  => esc_html__( 'Number of products per row.', 'angio' ),
			), 

			
			/* Image Background */ 
			array(
				'name'      => esc_html__( 'Background Image', 'angio' ),
				'id'        => 'wc_bg',
				'type'      => 'add_image',
				'std'       => '',
				'source'    => 'media_libary', // all, media_libary, external_link - "all" display select input
			), 

			/* Background Style */
			array(
				'name'      => esc_html__( 'Background Style', 'angio' ),
				'id'        => 'wc_bg_style',
				'type'      => 'select',
				'std'       => 'fixed',
				'options'   => array(
					array( 'name' => esc_html__( 'Classic', 'angio' ), 'value' => 'scroll' ),
					array( 'name' => esc_html__( 'Fixed', 'angio' ), 'value' => 'fixed' ),
				),
				'desc'      => esc_html__('Select background style.' , 'angio' ),
			),

			/* Sidebar */ 
			array(
				'name'       => esc_html__( 'Sidebar', 'angio' ),
				'id'         => 'wc_sidebar_position',
				'type'       => 'select',
				'std'        => 'disabled',
				'options'	 => array(
					array( 'name' => esc_html__( 'Disabled', 'angio' ), 'value' => 'disabled' ),
					array( 'name' => esc_html__( 'Left', 'angio' ), 'value' => 'left' ),
					array( 'name' => esc_html__( 'Right', 'angio' ), 'value' => 'right' ),
				),
				'desc'       => esc_html__( 'Select sidebar position. Ba default is disabled.', 'angio' ),
			), 

			// Sidebars  
			array(
				'name'       => esc_html__( 'Custom Sidebar', 'angio' ),
				'id'         => 'wc_custom_sidebar',
				'type'       => 'select',
				'std'        => '',
				'options'	 => angio_get_sidebars(),
				'desc'       => esc_html__( 'Select custom or primary sidebar.', 'angio' ),
				'dependency' => array(
					"element" => 'wc_sidebar_position',
					"value"   => array( 'left', 'right' )
			    )
			), 

		
		array(
			'type' => 'sub_close'
		),


		/* Product Page
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Product', 'angio' ),
			'sub_tab_id'   => 'sub-product'
		),
			

			/* Products Per Page */
			array(
				'name'  => esc_html__( 'Related Products Per Page', 'angio' ),
				'id'    => 'related_products_per_page',
				'type'  => 'range',
				'max'   => '999',
				'min'   => '1',
				'unit'  => 'products',
				'step'  => '1',
				'std'   => '3',
				'desc'  => esc_html__( 'Number of products per page.', 'angio' ),
			), 

			/* Products Per Row */
			array(
				'name'  => esc_html__( 'Related Products Per Row', 'angio' ),
				'id'    => 'related_products_per_row',
				'type'  => 'range',
				'max'   => '5',
				'min'   => '1',
				'unit'  => 'products',
				'step'  => '1',
				'std'   => '3',
				'desc'  => esc_html__( 'Number of products per row.', 'angio' ),
			), 

			/* Sidebar */ 
			array(
				'name'       => esc_html__( 'Sidebar', 'angio' ),
				'id'         => 'wcp_sidebar_position',
				'type'       => 'select',
				'std'        => 'disabled',
				'options'	 => array(
					array( 'name' => esc_html__( 'Disabled', 'angio' ), 'value' => 'disabled' ),
					array( 'name' => esc_html__( 'Left', 'angio' ), 'value' => 'left' ),
					array( 'name' => esc_html__( 'Right', 'angio' ), 'value' => 'right' ),
				),
				'desc'       => esc_html__( 'Select sidebar position. Ba default is disabled.', 'angio' ),
			), 

			// Sidebars  
			array(
				'name'       => esc_html__( 'Custom Sidebar', 'angio' ),
				'id'         => 'wcp_custom_sidebar',
				'type'       => 'select',
				'std'        => '',
				'options'	 => angio_get_sidebars(),
				'desc'       => esc_html__( 'Select custom or primary sidebar.', 'angio' ),
				'dependency' => array(
					"element" => 'wcp_sidebar_position',
					"value"   => array( 'left', 'right' )
			    )
			), 

		array(
			'type' => 'sub_close'
		),


	array(
		'type' => 'close'
	),




	/* ==================================================
	  Customize
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'Customize', 'angio' ),
		'tab_id'   => 'customize',
		'icon'     => 'paint-brush'
	),

		/* Colors
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Colors', 'angio' ),
			'sub_tab_id'   => 'sub-custom-colors',
		),


			// Base Color
			array(
				'name'   => esc_html__( 'Base Color', 'angio' ),
				'id'     => 'base_color',
				'type'   => 'color',
				'std'	 => '#cccccc',
				'output' => array(
					array(
						'property' => 'color',
						'element'  => array(
							'body',
							'.widget_rss li cite'
						)
					),
				)
			),

			// Accent Color
			array(
				'name'   => esc_html__( 'Accent Color', 'angio' ),
				'id'     => 'accent_color',
				'type'   => 'color',
				'std'	 => '#33f7dd',
				'output' => array(
					array(
						'property' => 'color',
						'element'  => array(
							'.brand-color',
							'.site .color',
							'.is-style-outline .wp-block-button__link',
							'.loader__bytes',
							'.header__menu ul ul a:hover',
							'.meta__date',
							'.comments__number',
							'#reply-title small a',
							'.widget a:hover',
							'.widget.widget_categories a:hover', 
							'.widget.widget_archive a:hover', 
							'.widget.widget_recent_entries a:hover', 
							'.widget.widget_meta a:hover', 
							'.widget.widget_nav_menu a:hover', 
							'.widget.widget_pages a:hover', 
							'.widget.widget_links',
							'.widget table#wp-calendar #next a:hover',
							'.widget table#wp-calendar #prev a:hover',
							'.mod__date',
							'.mod__readmore a',
							'.mod-news-3 .mod__date',
							'a .g:after',
							'.b-trigger .g:after',
							'body .mfp-arrow:hover',
							'.mfp-close:hover:after',
							'.menu-main__toggle:hover',
							// Toolkit
							'.wave-album__text',
							'.wave-album__buttons a:hover span',
							'.glitch-slider__desc',
							'.album-button:hover',
							'.event-h__date',
							'.mod-event-1 .mod__event-date',
							'.mod-event-2 .mod__event-date',

							// WooCommerce
							'.wcp-categories a:hover',
							'.wcp-title a:hover',
							'.wcp-categories a:hover',
							'.wcc-product a:hover',
							'.wcc-cats a:hover'
						)
					),
					array(
						'property' => 'background-color',
						'element'  => array(
							'.brand-bg-color',
							'.mod__inner.sticky .mod__title:before ',
							'.wp-block-tag-cloud a ',
							'.wp-block-button__link',
							'.wp-block-file .wp-block-file__button',
							'.paging-navigation .page-numbers.current',
							'.paging-navigation a:hover',
							'.attachment-post-link a:hover',
							'.loader__progress:after',
							'.widget button',
							'.widget .button',
							'.widget input[type="button"]',
							'.widget input[type="reset"]',
							'.widget input[type="submit"]',
							'.widget_tag_cloud a ',
							'.widget.widget_tag_cloud a:hover',
							'.message ',
							'input[type="submit"]:hover',
							'button:hover',
							'.btn:hover',						
							'.b-style-1:hover:before',
							'.meta-tags a:hover:before',
							'.comment .reply a:hover:before',
							// Toolkit
							'.audio-ctrl__position',
							// Woocommerce
							'.woocommerce .blockUI.blockOverlay',
							'.wc-button',
							'.added_to_cart',
							'.woocommerce #respond input#submit', 
							'.woocommerce a.button', 
							'.woocommerce button.button', 
							'.woocommerce input.button',
							'.woocommerce div.product form.cart .button',
							'.woocommerce-mini-cart__buttons a',
							'.woocommerce #respond input#submit.alt', 
							'.woocommerce a.button.alt', 
							'.woocommerce button.button.alt', 
							'.woocommerce input.button.alt',
							'.wc-pagination .current', 
							'.wc-pagination a:hover',
							'.woocommerce-account .woocommerce-MyAccount-navigation ul li a:hover',
							'.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a'
						)
					),
					array(
						'property' => 'border-color',
						'element'  => array(
							'blockquote',
							'.wp-block-quote',
							'.is-style-outline .wp-block-button__link',
							'input[type="submit"]',
							'button',
							'.btn',
							'input[type="submit"]:hover',
							'button:hover',
							'.btn:hover',
							'.b-style-4 .b-style-4__a:before',
							// Toolkit
							'.album-button',
							'.album-button:after',
							'.album-button:before',
							// Woocommerce
							'.woocommerce div.product .woocommerce-tabs ul.tabs li.active a',

						)
					),
				)
			),
		

			// Logo Margin 
			array(
				'name'     => esc_html__( 'Logo Margin', 'angio' ),
				'id'       => 'logo_margin',
				'type'     => 'css_remove_this',
				'options' => array(
					array(
						'type' 	=> 'text',
						'name'  => 'top',
						'css'   => 'margin-top',
						'value' => '0'
					),
					array(
						'type' 	=> 'text',
						'name'  => 'right',
						'css'   => 'margin-right',
						'value' => '0'
					),
					array(
						'type' 	=> 'text',
						'name'  => 'bottom',
						'css'   => 'margin-bottom',
						'value' => '0'
					),
					array(
						'type' 	=> 'text',
						'name'  => 'left',
						'css'   => 'margin-left',
						'value' => '0'
					),
				),
				'classes' => 'css-box-model css-margin', // hide-labels
				'desc'    => esc_html__('Set logo margin.', 'angio' ),
				'output' => array(
					array(
						'property' => 'margin',
						'element'  => array(
							'.header__logo a img',
						)
					),
				)

			),


		array(
			'type' => 'sub_close'
		),


		/* Header
		 -------------------------------- */
		array(
			'type' => 'sub_open',
			'sub_tab_name' => esc_html__( 'Header', 'angio' ),
			'sub_tab_id' => 'sub-custom-header',
		),

			// Logo
			array(
				'name'   => esc_html__( 'Logo Image', 'angio' ),
				'id'     => 'logo',
				'type'   => 'add_image',
				'source' => 'media_libary', // all, media_libary, external_link
				'desc'   => esc_html__('Add a logo image to the theme header.', 'angio' ),
			),

			// Logo Width
			array(
				'name'   => esc_html__( 'Logo Width', 'angio' ),
				'id'     => 'logo_width',
				'type'   => 'text',
				'std'	 => '70px',
				'desc'   => esc_html__('Set logo width.', 'angio' ),
				'output' => array(
					array(
						'property' => 'width',
						'element'  => array(
							'.header__logo a img',
						)
					),
				)
			),

		array(
			'type' => 'sub_close'
		),


		/* Footer
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Footer', 'angio' ),
			'sub_tab_id'   => 'sub-custom-footer',
		),

			// Display WPML Switcher
			array(
				'name' => esc_html__( 'WPML Language Switcher', 'angio' ),
				'id'   => 'wpml_switcher',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Display WPML plugin language switcher above main header on the right side. Please note WPML plugin must be installed.', 'angio' ),
			),


			// Copyright Note
			array(
				'name'   => esc_html__( 'Copyright Note', 'angio' ),
				'id'     => 'footer_note',
				'type'   => 'textarea',
				'std'    => '&copy; Copyright 2020 <a class="b-style-1" href="#" target="_blank">Angio Theme</a>.',
				'desc'   => esc_html__( 'Enter copyright note.', 'angio' ),
			),



		array(
			'type' => 'sub_close'
		),




	array(
		'type' => 'close'
	),


	/* ==================================================
	  Fonts
	================================================== */
	array(
		'type' => 'open',
		'tab_name' => esc_html__( 'Fonts', 'angio' ),
		'tab_id' => 'fonts',
		'icon' => 'font'
	),

		/* Google Fonts
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Google Web Fonts', 'angio' ),
			'sub_tab_id'   => 'sub-google-fonts',
		),
			array(
				'name' => esc_html__( 'Google Fonts', 'angio' ),
				'id'   => 'use_google_fonts',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'When this option is enabled, the text elements will be automatically replaced with the Google Web Fonts.', 'angio' ),
			),
			/*
			




			Inconsolata:wght@400;700|Karla:ital,wght@0,400;0,700;1,400;1,700|Lato:ital,wght@0,400;0,700;1,400;1,700|News+Cycle:wght@400;700|Chivo:300,700&display=swap

			 */
			array(
				'name'    => esc_html__( 'Google Font Code', 'angio' ),
				'id'      => 'google_fonts',
				'type'    => 'textarea',
				'std'     => 'Poppins:300,300i,400,400i,500,500i,600,600i,800,800i&display=swap&subset=latin-ext',
				'tinymce' => 'false',
				'height'  => '50',
				'desc'    => esc_html__( 'Add Google Fonts family.', 'angio' ),
				'dependency' => array(
					"element" => 'use_google_fonts',
					"value"   => array( 'on' )
			    )
			),
		array(
			'type' => 'sub_close'
		),


	array(
		'type' => 'close'
	),


	/* ==================================================
	  Socials
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'Socials', 'angio' ),
		'tab_id'   => 'socials',
		'icon'     => 'share'
	),

		/* Socials
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Socials', 'angio' ),
			'sub_tab_id'   => 'sub-socials-links',
		),

			array(
				'name'       => esc_html__( 'Socials', 'angio' ),
				'sortable'   => true,
				'array_name' => 'socials',
				'id'         => array(
					array( 'name' => 'service', 'id' => 'service', 'label' => 'Social Shortcut:', 'type' => 'text' ),
					array( 'name' => 'link', 'id' => 'link', 'label' => 'Link:', 'type' => 'text' )
				),
				'type'        => 'sortable_list',
				'button_text' => esc_html__( 'Add Social', 'angio' ),
				'classes'     => 'socials-sortable-list',
				'desc'        => esc_html__( 'Add social links.', 'angio' )
			),


		array(
			'type' => 'sub_close'
		),


	array(
		'type' => 'close'
	),


	/* ==================================================
	  Permalinks
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'Permalinks', 'angio' ),
		'tab_id'   => 'links',
		'icon'     => 'link'
	),

		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Permalinks', 'angio' ),
			'sub_tab_id'   => 'sub-section-permalinks',
		),


			// Music
			array(
				'name' => esc_html__( 'Album Slug', 'angio' ),
				'id'   => 'album_slug',
				'type' => 'text',
				'std'  => 'album',
				'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'angio' )
			),
			array(
				'name' => esc_html__( 'Album Filter 1 Slug', 'angio' ),
				'id'   => 'album_cats_slug',
				'type' => 'text',
				'std'  => 'album-category',
				'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'angio' )
			),


			// Events
			array(
				'name' => esc_html__( 'Event Slug', 'angio' ),
				'id'   => 'event_slug',
				'type' => 'text',
				'std'  => 'event',
				'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'angio' )
			),
			array(
				'name' => esc_html__( 'Event Filter 1 Slug', 'angio' ),
				'id'   => 'event_cats_slug',
				'type' => 'text',
				'std'  => 'event-category',
				'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'angio' )
			),


		array(
			'type' => 'sub_close'
		),


	array(
		'type' => 'close'
	),


	/* ==================================================
	  Sidebars
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'Sidebars', 'angio' ),
		'tab_id'   => 'sidebars',
		'icon'     => 'bars'
	),
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Sidebars', 'angio' ),
			'sub_tab_id'   => 'sub-sidebars'
		),
			array(
				'name'       => esc_html__( 'Sidebars', 'angio' ),
				'sortable'   => false,
				'array_name' => 'custom_sidebars',
				'id'         => array(
				 	array( 'name' => 'name', 'id' => 'sidebar', 'label' => 'Name:', 'type' => 'text' )
				 ),
				'type'        => 'sortable_list',
				'button_text' => esc_html__( 'Add Sidebar', 'angio' ),
				'desc'        => esc_html__( 'Add your custom sidebars.', 'angio' )
			),
		array(
			'type' => 'sub_close'
		),
	array(
		'type' => 'close'
	),


	/* ==================================================
	  Advanced
	================================================== */
	array(
		'type'     => 'open',
		'tab_name' => esc_html__( 'Advanced', 'angio' ),
		'tab_id'   => 'advanced',
		'icon'     => 'wrench'
	),


		/* AJAX
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Ajax', 'angio' ),
			'sub_tab_id'   => 'sub-ajax'
		),

			// Ajax
			array(
				'name' => esc_html__( 'Ajax Load', 'angio' ),
				'id'   => 'ajaxed',
				'type' => 'switch_button',
				'std'  => 'on',
				'desc' => esc_html__( 'Enable if you want ajax loading.', 'angio' ),
			),

			// Ajax Selectors
			array(
				'name'       => esc_html__( 'Selectors Blacklist', 'angio' ),
				'id'         => 'blacklist_selectors',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add selectors (Note: divide links with linebreaks (Enter)). These elements will not be processed by AJAX.', 'angio' ),
				'dependency' => array(
					"element" => 'ajaxed',
					"value"   => array( 'on' )
			    )
			),

			// Reload Scripts
			array(
				'name'       => esc_html__( 'Reload Scripts', 'angio' ),
				'id'         => 'reload_scripts',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add strings for reloaded scripts (Note: divide links with linebreaks (Enter)). These scripts will be reloaded after page loaded by AJAX.', 'angio' ),
				'dependency' => array(
					"element" => 'ajaxed',
					"value"   => array( 'on' )
			    )
			),

			// Reload Containers
			array(
				'name'       => esc_html__( 'Reload Containers', 'angio' ),
				'id'         => 'reload_containers',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add strings for reloaded containers (Note: divide links with linebreaks (Enter)). These containers will be reloaded after page loaded by AJAX.', 'angio' ),
				'dependency' => array(
					"element" => 'ajaxed',
					"value"   => array( 'on' )
			    )
			),

			// Exclude Links
			array(
				'name'       => esc_html__( 'Links Blacklist', 'angio' ),
				'id'         => 'blacklist_links',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add links that should be excluded from AJAX loader (Note: divide links with linebreaks (Enter)). These pages will not be loaded by AJAX.', 'angio' ),
				'dependency' => array(
					"element" => 'ajaxed',
					"value"   => array( 'on' )
			    )
			),


		array(
			'type' => 'sub_close'
		),


		/* Plugins
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Plugins', 'angio' ),
			'sub_tab_id'   => 'sub-plugins'
		),

			// Facebook JSSDK
			array(
				'name' => esc_html__( 'Facebook JSSDK', 'angio' ),
				'id'   => 'fbsdk',
				'type' => 'switch_button',
				'std'  => 'off',
				'desc' => esc_html__( 'Connect site with Facebook JS SDK. This is necessary to display widgets from Facebook.', 'angio' ),
			),
		array(
			'type' => 'sub_close'
		),


		/* Import/Export
		 -------------------------------- */
		array(
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Import/Export', 'angio' ),
			'sub_tab_id'   => 'sub-import'
		),
			array(
				'type' => 'export'
			),
			array(
				'type' => 'import'
			),
		array(
			'type' => 'sub_close'
		),

	array(
		'type' => 'close'
	),


	/* ==================================================
	    Hidden fields
	 ================================================== */
	array(
		'type'  => 'hidden_field',
		'id'    => 'theme_name',
		'value' => 'angio'
	),

);


/* ==================================================
  Init Panel
================================================== */

/* Class arguments */
$args = array(
	'menu_name'       => esc_html__( 'Theme Panel', 'angio' ),
	'option_name'     => 'angio_panel_opts',
	'css_option_name' => 'angio_css',
	'menu_icon'       => '',
);

/* Add class instance */
$main_panel = new RascalsThemePanel( $args, $angio_main_options );


/* ==================================================
  Panel Helpers
================================================== */
function angio_opts(){
   global $main_panel;
   return $main_panel;
}

function angio_esc( $t ){
   global $main_panel;
   return $main_panel->esc( $t );
}
function angio_get_option( $option, $default = null ){
   global $main_panel;
   return $main_panel->get_option( $option, $default );
}
function angio_get_meta_option( $id = null, $option = null, $default = null, $single = true ){

 	$opt = get_post_meta( $id, $option, $single );
	if ( $opt && ! empty( $opt ) ) {
		return $opt;
	}
	return $default;
}
function angio_get_options( ){
  	return get_option( 'angio_panel_opts' );
}
function angio_get_image_src( $option, $size, $default = null ){
   global $main_panel;
   return $main_panel->get_image( $option, $size, $default );
}
function angio_get_sidebars( ){
	$panel_options = get_option( 'angio_panel_opts' );
	$default_list = array(
		array( 'name' => esc_html__( 'Primary Sidebar', 'angio' ), 'value' => '_default' ),
	);
	if ( isset( $panel_options[ 'custom_sidebars' ] ) ) {
		$s_list = $panel_options[ 'custom_sidebars' ];
		$temp_list = [];
		foreach ($s_list as $key => $li) {
			$temp_list[$key]['name'] = $li['name'];
			$temp_list[$key]['value'] = sanitize_title_with_dashes( $li['name'] );
		}
		$s_list = array_merge( $default_list, $temp_list);
	} else {
		$s_list = $default_list;
	}
	return $s_list;
}