<?php
/**
 * Theme Name: 		Angio
 * Theme Author: 	Mariusz Rek - Rascals Themes
 * Theme URI: 		http://rascalsthemes.com/theme/angio
 * Author URI: 		http://rascalsthemes.com
 * File:			functions.php
 * @package angio
 * @since 1.0.0
 */


/* ==================================================
   Set up the content width value based on the theme's design.
================================================== */
if ( ! isset( $content_width ) ) {
	$content_width = 1180;
}


/* ==================================================
  Theme Translation 
================================================== */
load_theme_textdomain( 'angio', get_template_directory() . '/languages' );


/* ==================================================
  Admin Panel 
================================================== */
require_once( trailingslashit( get_template_directory() ) . '/admin/admin-init.php' );


/* ==================================================
  Theme Setup 
================================================== */
if ( ! function_exists( 'angio_setup' ) ) :

	/**
	 * angio setup.
	 *
	 * Set up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support post thumbnails.
	 *
	 */

function angio_setup() {

	// Add RSS feed links to <head> for posts and comments. 
	add_theme_support( 'automatic-feed-links' );

	// Gutenberg support 
	add_theme_support( 'gutenberg' );
	add_theme_support( 'wide-images' );
	add_theme_support( 'align-wide' );


	// Enqueue editor styles.
	add_editor_style( 'style-editor.css' );

	// Add Title tag 
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails, and declare two sizes. 
	add_theme_support( 'post-thumbnails' );

	set_post_thumbnail_size( 150, 150, array( 'center', 'center' ) );

	// This theme uses wp_nav_menu() in two locations. 
	register_nav_menus( array(
		'main'        => esc_html__( 'Main Menu', 'angio' ),
	) );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	// This theme uses its own gallery styles. 
	add_filter( 'use_default_gallery_style', '__return_false' );

	// This theme support WooCommerce
	add_theme_support( 'woocommerce' );

	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

}

add_action( 'after_setup_theme', 'angio_setup' );

endif; 

// Events manager order fix
function angio_events_manager_update() {

	$args = [
		'post_type'        => 'angio_events',
		'post_status'      => 'publish, pending, draft, future, private, trash',
		'numberposts'      => '-1'
	];

	$events = get_posts( $args );
	
 	foreach( $events as $event ) {
 		$post_id = $event->ID;
 		if ( empty( get_post_meta( $post_id, '_event_order' ) ) ) {

			$event_date_start = strtotime( get_post_meta( $post_id, '_event_date_start', true ) );
			$event_time_start = strtotime( get_post_meta( $post_id, '_event_time_start', true ) );
			$event_order = '';
			$new_date = date_i18n( 'Y-m-d', $event_date_start );
			$new_time = date_i18n( 'H:i:s', $event_time_start );
			$event_order = $new_date . ' ' . $new_time;
			update_post_meta( $post_id, '_event_order', $event_order );
		}

 	}

}


// Add a theme init flag after activation 
function angio_active () {

	// Add new compatible option
	add_option( 'rascals_toolkit', 'angio' );
	wp_safe_redirect( admin_url() . 'themes.php?page=admin-welcome' );

	// Fixes
	// Events Manager Update
	angio_events_manager_update();
}
add_action('after_switch_theme', 'angio_active');

// Delete a theme init flag after deactivation 
function angio_dective () {

	delete_option( 'rascals_toolkit' );

	// Remove outdated compatibility with the extensions plug-in
	delete_option( 'angio_init' );
}
add_action( 'switch_theme', 'angio_dective' );


/* ==================================================
  Theme Toolkit
================================================== */
function angio_toolkit( $instance = null ) {

	if ( class_exists( 'Angio_Toolkit' ) && $instance === null ) {
		return true;
	} elseif ( class_exists( 'Angio_Toolkit' ) && $instance !== null ) {
		$toolkit = angioToolkit();
		if ( $instance !== null && property_exists( 'Angio_Toolkit', $instance ) ) {
			return $toolkit->$instance;
		} else {
			return false;
		}
		
		return $toolkit;
	}

	return false;

} 


/* ==================================================
  Google Fonts 
================================================== */
function angio_fonts_url() {

    	$font_url = '';
	    
	    if ( angio_get_option( 'use_google_fonts', 'off' ) === 'on' ) {
	        if ( angio_get_option( 'google_fonts', false ) ) {
	             $font_url = add_query_arg( 'family', esc_attr( angio_get_option( 'google_fonts', false ) ), "//fonts.googleapis.com/css" );
	        }
    	}

    return $font_url;
}


// Enqueue scripts and styles.
function angio_fonts_scripts() {
    wp_enqueue_style( 'angio-fonts', angio_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'angio_fonts_scripts' );


/* ==================================================
   Required styles and scripts
================================================== */

if ( ! function_exists( 'angio_scripts_and_styles' ) ) :
function angio_scripts_and_styles() {
	
	global $post, $wp_query;

	/* Styles
	 -------------------------------- */

	// Extra Icons
	wp_enqueue_style( 'icomoon-font', get_template_directory_uri() . '/css/icomoon.css' );
	
	// Grid
	wp_enqueue_style( 'angio-grid',  get_template_directory_uri() . '/css/grid.css' );

	// Main styles
	wp_enqueue_style( 'angio-style', get_stylesheet_uri() );


	/* Scripts
	 -------------------------------- */
	/* Add comment reply script when applicable */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	if ( angio_get_option( 'ajaxed', 'off' )  === 'on' ) {
		$ajaxed = 1;
	} else {
		$ajaxed = 0;
	}

	// Animation 
	wp_enqueue_script( 'gsap', get_template_directory_uri() . '/js/gsap.min.js', array(), false, true );

	// Gsap ScrollMagic
	if ( angio_get_option( 'scrollmagic', 'off' ) === 'on' ) {
		wp_enqueue_script( 'gsap-scrollmagic', get_template_directory_uri() . '/js/scrollmagic.min.js', false, false, true );
	}

	// Smooth Scrollbars
	wp_enqueue_script( 'smooth-scrollbar', get_template_directory_uri() . '/js/smooth-scrollbar.min.js' , array(), false, true );

	// Enable FB JSSDK 
	if ( angio_get_option( 'fbsdk', 'off' ) === 'on' ) {
		wp_enqueue_script( 'facebook-jssdk', 'https://connect.facebook.net/' . esc_attr( get_locale() ) . '/sdk.js#xfbml=1&version=v2.7', array(), false, true );
	}


	/* AJAX Loader
	 -------------------------------- */
	
	if ( $ajaxed === 1 ) {

		// Load AJAX loader if is enabled
		wp_enqueue_script( 'axloader', get_template_directory_uri() . '/js/axloader.js', false, false, true );
	
	 	// Ajax Containers 
		$default_reload_containers = array(
			'#wpadminbar'
		);
		$reload_containers = angio_get_option( 'reload_containers' );
	    $reload_containers = angio_filter_field( angio_get_option( 'reload_containers' ), $default_reload_containers );
	    
	    // Ajax Scripts 
		$default_reload_scripts = array(
			'admin-bar.min.js',
			'waypoints.min.js',
			// WC
			'woocommerce/assets/js/frontend/checkout.min.js',
			'woocommerce/assets/js/frontend/country-select.min.js',
			'woocommerce/assets/js/frontend/single-product.min.js',
			'woocommerce/assets/js/frontend/woocommerce.min.js',
			'contact-form-7/includes/js/scripts.js',
			'elementor/assets/lib/swiper/swiper.min.js',
			'elementor/assets/js/frontend.min.js'
		);
		$reload_scripts = angio_filter_field( angio_get_option( 'reload_scripts' ), $default_reload_scripts);

		
	    // Ajax Selectors Blacklist 
		$default_blacklist_selectors = array(
			'.ajax-off',
			// WC
			'.woocommerce-message .restore-item',
			'.product-remove .remove',
			'.remove_from_cart_button',
			'.add_to_cart_button',
			'.single_add_to_cart_button',
			'.ajax_add_to_cart',
			'.wc-tabs li a',
			'ul.tabs li a',
			'.woocommerce-review-link',
			'.woocommerce-Button.download',
			'.woocommerce-MyAccount-downloads-file'
		);
		
		$blacklist_selectors = angio_filter_field( angio_get_option( 'blacklist_selectors' ), $default_blacklist_selectors);


	    // Ajax Links Blacklist
		$default_blacklist_links = array();
	    $blacklist_links = angio_filter_field( angio_get_option( 'blacklist_links' ), $default_blacklist_links);

		// Get AJAX path 
		$option_home = 'home';
		$dir = parse_url( get_option( $option_home ) );
		if ( ! isset( $dir[ 'path' ] ) ) {
			$dir[ 'path' ] = '';
		}

		// Permalinks 
		$permalinks = 0;
		if ( get_option('permalink_structure') ) {
			$permalinks = 1;
		}

		$js_vars = array(
			'baseUrl'            => esc_url( home_url('/') ),
			'path'               => get_template_directory_uri(),
			'dir'                => esc_url( $dir[ 'path' ] ),
			'ajaxed'             => esc_attr( $ajaxed ),
			'permalinks'         => $permalinks,
			'blacklistSelectors' => esc_attr( implode( ",", $blacklist_selectors ) ),
			'reloadScripts'      => esc_attr( implode( ",", $reload_scripts ) ),
			'reloadContainers'   => esc_attr( implode( ",", $reload_containers ) ),
			'blacklistLinks'     => esc_attr( implode( ",", $blacklist_links ) ),
			
		);
	} else {
		$js_vars = array(
			'ajaxed'  => esc_attr( $ajaxed ),
			'path'    => get_template_directory_uri(),
			'baseUrl' => esc_url( home_url('/') ),
		);
	}
	
	wp_enqueue_script( 'angio-theme-scripts', get_template_directory_uri() . '/js/theme.js' , false, false, true );
	wp_localize_script( 'angio-theme-scripts', 'themeVars', $js_vars );
	wp_localize_script( 'angio-theme-scripts', 'ajax_action', array('ajaxurl' => admin_url('admin-ajax.php'), 'ajax_nonce' => wp_create_nonce( 'ajax-nonce') ) );

	
}

add_action( 'wp_enqueue_scripts', 'angio_scripts_and_styles' );
endif;


/* ==================================================
  AJAX Filter field 
================================================== */
function angio_filter_field( $elements = false, $defaults = array() ) {

	$elements = preg_replace( '/\n$/','',preg_replace('/^\n/','',preg_replace('/[\r\n]+/',"\n", $elements) ) );
	$elements = str_replace("\n", ',', $elements );
    $elements = explode( ",", $elements );
    $elements = array_unique ( array_merge( $defaults, $elements ) );
    $elements = array_filter( $elements );

    return $elements;

}


/* ==================================================
  Sidebars 
================================================== */
function angio_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'angio' ),
		'id'            => 'primary-sidebar',
		'description'   => esc_html__( 'Main sidebar that appears on the left or right.', 'angio' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// Custom sidebars
	if ( angio_get_option( 'custom_sidebars', false ) ) {
		
		foreach ( angio_get_option( 'custom_sidebars' ) as $sidebar ) {
			
			$id = sanitize_title_with_dashes( $sidebar[ 'name' ] );
			register_sidebar( array(
				'name'          => $sidebar[ 'name' ],
				'id'            => $id,
				'description'   => esc_html__( 'Custom sidebar created in admin options.', 'angio' ),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			));
		}
	}

}
add_action( 'widgets_init', 'angio_widgets_init' );


/* ==================================================
  Include necessary files
================================================== */
require_once( trailingslashit( get_template_directory() ) . '/inc/modules.php' );
require_once( trailingslashit( get_template_directory() ) . '/inc/filters.php' );
require_once( trailingslashit( get_template_directory() ) . '/inc/helpers.php' );
require_once( trailingslashit( get_template_directory() ) . '/inc/ajax.php' );
require_once( trailingslashit( get_template_directory() ) . '/inc/template-tags.php' );	