<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            header.php
 * @package angio
 * @since 1.0.0
 */


?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />

    <?php wp_head(); ?>

</head>

<body <?php body_class() ?>>
<?php
if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open(); 
}
?>

<?php 
///////////
// NOISY //
///////////

if ( angio_get_option( 'noisy', 'off' )  === 'on' ) : ?>

<div class="noisy"></div>

<?php endif ?>

<?php 
////////////
// LOADER //
////////////
if ( ! is_customize_preview()  ) : ?>
    <?php if ( angio_get_option( 'ajaxed', 'off' )  === 'on' && angio_get_option( 'page_transition', 'off' ) === 'on' ) {
        echo angio_loader();
    } ?>
<?php endif; ?>

<?php 
/////////////////////
// PAGE TRANSITION //
/////////////////////

if ( angio_get_option( 'page_transition', 'off' )  === 'on' ) : ?>

<div class="page-trans glitch-disappear"></div>

<?php endif ?>

<?php 
////////////
// CURSOR //
////////////
?>
<?php if ( angio_get_option( 'cursor_effects', 'off' )  === 'on' ) : ?>
<div id="cursor"><div class="cursor__body"></div><div class="cursor__body-inner"></div><div class="cursor__body-text"></div></div>
<?php endif; ?>

<?php
/*
Defaults values for main navigation 
 */
$defaults_main = array(
    'theme_location'  => 'main',
    'menu'            => '',
    'container'       => 'div',
    'container_class' => '',
    'menu_class'      => 'primary',
    'fallback_cb'     => 'wp_page_menu',
    'depth'           => 3
); 
?>
<?php 
$header_style = angio_get_option( 'header_style', 'hybrid' );
?>
<header id="header" class="header-<?php echo esc_attr( $header_style ) ?>">

	

    <div class="header__container container--full">

        <?php 
        //////////
        // LOGO //
        //////////
         ?>
        <div class="header__logo">
        	<div class="logo">
	            <?php
	            $logo = get_template_directory_uri() . '/images/logo.svg';
	            echo '<a href="' . esc_url( home_url('/') ) . '">';
	            echo '<img src="' . angio_get_image_src( 'logo', 'full', $logo ) . '" alt="' . esc_attr__( 'Logo Image', 'angio' ) . '">';
	            echo '</a>';
	            ?>
	        </div>
        </div>

        <?php 
        /////////////////////
        // TOP  NAVIGATION //
        /////////////////////
         ?>
        <?php if ( $header_style === 'hybrid' || $header_style === 'classic' ) : ?>
            <nav class="header__menu menu-top js-desktop-menu">
                <?php wp_nav_menu( $defaults_main ); ?>
            </nav>
        <?php endif; ?>


        <?php 
        //////////////////////
        // WOOCOMMERCE CART //
        //////////////////////

         ?>
		<?php if ( class_exists( 'woocommerce' ) && angio_get_option( 'wc_cart', 'on' ) === 'on' ) : ?>
			<?php  
			 	$count = WC()->cart->get_cart_contents_count();
	    		$wc_link = wc_get_cart_url();

			?>
			<div class="cart-widget-holder">
				<a href="#" class="cart-widget-button js-cart-button magneto">
					<span class="cart-icon">
						<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 12 16" xml:space="preserve">
						<path class="st0" d="M9,4V3c0-1.7-1.3-3-3-3S3,1.3,3,3v1H0v10c0,1.1,0.9,2,2,2h8c1.1,0,2-0.9,2-2V4H9z M4,3c0-1.1,0.9-2,2-2
							s2,0.9,2,2v1H4V3z"></path>
						</svg>
					    <span class="cart-widget-counter brand-bg-color js-cart-counter"><?php echo esc_html( $count) ?></span>
					</span>
				</a>
				<div class="cart-widget js-cart-widget">
					<div class="cart-widget__header">
						<div class="cart-widget__title">
							<h6><?php esc_html_e( 'Cart review', 'angio' ) ?></h6>
						</div>
						<a href="#" class="cart-widget__close js-cart-widget-close">
							<div class="x-icon">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" focusable="false" width="1em" height="1em" style="-ms-transform: rotate(360deg); -webkit-transform: rotate(360deg); transform: rotate(360deg);" preserveAspectRatio="xMidYMid meet" viewBox="0 0 512 512"><path d="M405 136.798L375.202 107 256 226.202 136.798 107 107 136.798 226.202 256 107 375.202 136.798 405 256 285.798 375.202 405 405 375.202 285.798 256z" fill="#626262"/></svg>
							</div>
						</a>
					</div>
					<div class="widget_shopping_cart_content"><?php woocommerce_mini_cart(); ?></div>
				</div>
			</div>




		 <?php endif ?>
        <?php 
        //////////////////////
        // BACKGROUND MUSIC //
        //////////////////////
        if ( function_exists( 'angio_toolkit_get_audio' ) && angio_get_option( 'background_player', 'off' ) === 'on' ) : 
            if ( angio_get_option( 'bg_player_track' ) ) :
        ?>

                <?php 
                    $bg_tracks_id = angio_get_option( 'bg_player_track' );
                    $bg_tracks_ids = angio_get_option( 'bg_player_ids', '' );
                    $tracks = angio_toolkit_get_audio( $bg_tracks_id, $bg_tracks_ids );
                ?>

                <?php if ( $tracks ) : ?>
                <div class="menu-extra-button magneto">	
                    <a href="<?php echo esc_url( $tracks[0]['url'] ) ?>" class="bg-player rp">
                        <span class="bg-player__loader"></span>
                        <span class="bg-player__eq">
                            <span class="eq-bar eq-bar1"></span>
                            <span class="eq-bar eq-bar2"></span>
                            <span class="eq-bar eq-bar3"></span>
                            <span class="eq-bar eq-bar4"></span>
                            <span class="eq-bar eq-bar5"></span>
                        </span>
                    </a>
                </div>
                <?php endif; ?>
            <?php endif; ?>
        <?php endif; ?>

		<div class="header__layer-menu">
            <?php 
            //////////////////////
            // LAYER NAVIGATION //
            //////////////////////
            ?>
            	
        	 <div class="l-menu js-layer-menu">
                <div class="l-menu__wrap">
                    <div class="l-menu__inner container container--full">
                        <nav class="menu-main js-create-b-style-3 js-layer-menu-nav">
                            <?php wp_nav_menu( $defaults_main ); ?>
                        </nav>
                    </div>
                </div>
                <div class="l-menu-bg js-layer-menu-bg"></div>
            </div>
            <div class="menu-extra-button magneto">	
	            <a href="#" class="l-menu-btn menu-button js-menu-button">
				   <div class="dots-wrap">
				      <div class="dot-row _1">
				         <div class="dot _1"><span></span></div>
				         <div class="dot _2"><span></span></div>
				         <div class="dot _3"><span></span></div>
				      </div>
				      <div class="dot-row _2">
				         <div class="dot _1"><span></span></div>
				         <div class="dot _2"><span></span></div>
				         <div class="dot _3"><span></span></div>
				      </div>
				      <div class="dot-row _3">
				         <div class="dot _1"><span></span></div>
				         <div class="dot _2"><span></span></div>
				         <div class="dot _3"><span></span></div>
				      </div>
				   </div>
				   <div class="menu-loading">
				      <svg class="circular" viewBox="25 25 50 50">
				         <circle class="path" cx="50" cy="50" r="24" style="transform-origin: 0px 0px;" data-svg-origin="26 26"> </circle>
				      </svg>
				   </div>
				</a>
			</div>

        </div>
    </div>
</header>

<div id="app">
    <div id="ajax-content">