<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            ajax.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* ==================================================
  Load More 
================================================== */
if ( ! function_exists( 'angio_load_more' ) ) :
function angio_load_more() {

    $nonce       = $_POST['ajax_nonce'];
    $opts        = $_POST['opts'];
    $module_opts = $_POST['module_opts'];
    $filter      = $_POST['filter'];
    $output      = '';

    if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) ) {
        die( 'Busted!' );
    }
    if ( ! isset( $opts ) && ! isset( $module_opts ) ) {
        die();
    }

    // Date format
    $date_format = get_option( 'date_format' );

    // Begin Loop
    $args = angio_prepare_wp_query( $filter, $opts['paged'] );

    $ajax_query = new WP_Query();
    $ajax_query->query( $args );

    // Check if this is the last page 
    $last_page = '';
    if ( intval( $args['paged'] ) === intval( $ajax_query->max_num_pages ) ) {
        $last_page = 'last-page';
    } 

    // Only for events list module
    $next_month = '';
    $month_count = 0;

    // Begin Loop
    if ( $ajax_query->have_posts() ) {
        
        while ( $ajax_query->have_posts() ) {
            $ajax_query->the_post();
            if ( function_exists( 'angio_get_taxonomies' ) ) {
                $cat_separator = '';
                $cat_link = false;
                $tax_args = array(
                    'id'         => $ajax_query->post->ID,
                    'tax_name'   => 'category',
                    'separator'  => '',
                    'link'       => $cat_link,
                    'limit'      => 2,
                    'show_count' => true

                );
                $cats_html = angio_get_taxonomies( $tax_args );
            } else {
                $cats_html = '';
            }

            // Excerpt
            if ( isset( $module_opts['excerpt'] ) && $module_opts['excerpt'] === 'true' ) {
                if ( has_excerpt() ) {
                    $excerpt = wp_trim_words( get_the_excerpt(), 30, '' );
                } else {
                    $excerpt = wp_trim_words( strip_shortcodes( get_the_content() ), 30, '' ); 
                }
            } 

            if ( function_exists( $module_opts['module'] ) ) {

                $module_args = array(
                    'post_id'       => $ajax_query->post->ID,
                    'thumb_size'    => $module_opts['thumb_size'],
                    'lazy'          => false,
                    'title'         => get_the_title(),
                    'permalink'     => get_permalink(),
                    'author'        =>  get_the_author_meta( 'display_name', $ajax_query->post->post_author ),
                    'date'          => get_the_time( $date_format ),
                    'posts_cats'    => $cats_html,
                    'excerpt'       => $excerpt,
                    'readmore'      => $module_opts['readmore'],
                    'classes'       => $module_opts['classes'],
                    'posts_classes' => implode( ' ', get_post_class( '', $ajax_query->post->ID ) ),
                );

                // Custom modules settings 
                if ( $module_opts['module'] === 'angio_video_module1'  ) {
                    $module_args['ca'] = $module_opts['ca'];
                    
                }
                // Flex Grid
                $output .= '<div class="flex-item ' . esc_attr( $last_page ) . '">';
                $output .= $module_opts['module']( $module_args );
                $output .= '</div>';
              
            }
  
        } 
        angio_esc( $output );

        die();
        return;
    } // end have_posts

    echo 'no_results';

    die();
    return;
    
}
add_action('wp_ajax_nopriv_angio_load_more', 'angio_load_more');
add_action('wp_ajax_angio_load_more', 'angio_load_more');
endif;