<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            filters.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* ==================================================
  Check if taxonomy is empty
  ver 1.0.0
================================================== */
if ( ! function_exists( 'angio_tax_is_empty' ) ) :
function angio_tax_is_empty( $atts, $t_query ) {

    $query_args = angio_prepare_wp_query( $atts, 0 );

    $query_args['posts_per_page'] = -1;

    if ( isset( $query_args['tax_query'] ) ) {

        array_push($query_args['tax_query'], $t_query);
        $query_args['tax_query'] = array_unique($query_args['tax_query'], SORT_REGULAR);
        $t_query  = new WP_Query($query_args);
        $count = $t_query->post_count;
        if ( $count === 0 ) {
            return true;
        }
    }
    
    return false;

}
endif;


/* ==================================================
  Prepare Events Filter
  ver 1.0.0
================================================== */
if ( ! function_exists( 'angio_prepare_events_filter' ) ) :
function angio_prepare_events_filter( $args ) {

    if ( ! isset( $args ) || ! isset( $args['filter_atts'] ) ) {
        return false;
    }

    $filter_atts = $args['filter_atts'];

    if ( isset( $filter_atts[0] ) ) {
        $filter_atts = $filter_atts[0];
    }

    // Extra parameters 
    $filter_atts['filter_type']       = $args['ajax_filter'];
    $filter_atts['show_filters']      = $args['show_filters'];
    $filter_atts['filter_sel_method'] = $args['filter_sel_method'];
    $filter_atts['event_type_tax']    = 'angio_event_type';
    $filter_atts['post_type']         = 'angio_events';
    $filter_atts['sort_order']        = 'events_date';

    // All available filters (taxonomies)  
    $taxes = array(
        'angio_event_type' => array(
            'tax_name' => 'angio_event_type',
            'ids'      => 'event_type_ids', 
            'slugs'    => 'event_type_slugs',
            'label'    => 'event_type_label',
        ),
        'angio_event_cats' => array(
            'tax_name' => 'angio_event_cats',
            'ids'      => 'category_ids', 
            'slugs'    => 'category_slugs',
            'label'    => 'category_label',
        ),
       
    );

    $filter_atts['taxes'] = $taxes;

    return angio_prepare_filter_taxonomies($filter_atts);
}

endif;


/* ==================================================
  Prepare Albums Filter
  ver 1.0.0
================================================== */
if ( ! function_exists( 'angio_prepare_albums_filter' ) ) :
function angio_prepare_albums_filter( $args ) {

    if ( ! isset( $args ) || ! isset( $args['filter_atts'] ) ) {
        return false;
    }

    $filter_atts = $args['filter_atts'];

    if ( isset( $filter_atts[0] ) ) {
        $filter_atts = $filter_atts[0];
    }

    // Extra parameters 
    $filter_atts['filter_type']       = $args['ajax_filter'];
    $filter_atts['show_filters']      = $args['show_filters'];
    $filter_atts['filter_sel_method'] = $args['filter_sel_method'];
    $filter_atts['post_type']         = 'angio_albums';

    // All available filters (taxonomies)  
    $taxes = array(
        'angio_albums_cats' => array(
            'tax_name' => 'angio_album_cats',
            'ids'      => 'category_ids', 
            'slugs'    => 'category_slugs',
            'label'    => 'category_label',
        ),
    );

    $filter_atts['taxes'] = $taxes;
    return angio_prepare_filter_taxonomies($filter_atts);
}
endif;


/* ==================================================
  Prepare Posts Filter
  ver 1.0.0
================================================== */
if ( ! function_exists( 'angio_prepare_posts_filter' ) ) :
function angio_prepare_posts_filter( $args ) {

   if ( ! isset( $args ) || ! isset( $args['filter_atts'] ) ) {
        return false;
    }

    $filter_atts = $args['filter_atts'];

    if ( isset( $filter_atts[0] ) ) {
        $filter_atts = $filter_atts[0];
    }

    // Extra parameters 
    $filter_atts['filter_type']       = $args['ajax_filter'];
    $filter_atts['show_filters']      = $args['show_filters'];
    $filter_atts['filter_sel_method'] = $args['filter_sel_method'];

    // All available filters (taxonomies)  
    $taxes = array(
        'category' => array(
            'tax_name' => 'category',
            'ids'      => 'category_ids', 
            'slugs'    => 'category_slugs',
            'label'    => 'category_label',
        ),
    );

    $filter_atts['taxes'] = $taxes;
    return angio_prepare_filter_taxonomies($filter_atts);

}
endif;


/* ==================================================
  Prepare Filter Taxonomies
  ver 1.0.0
================================================== */
if ( ! function_exists( 'angio_prepare_filter_taxonomies' ) ) :
function angio_prepare_filter_taxonomies( $atts ) {

    if ( isset( $atts[0] ) ) {
        $atts = $atts[0];
    }

    if ( ! isset( $atts['post_type'] ) ) {
        $atts['post_type'] = 'post';
    }

    $temp_taxes = array();
    $count = 1;
    $label = 'category_label';
    $ids_name = 'category_ids';
    $slugs_name = 'category_slugs';
    $multiple_filters  = ( $atts['filter_type'] === 'multiple-filters' ? true : false );

    // Old taxonomies 
    if ( $multiple_filters === false && ! isset( $atts[$label] ) ) {
        $atts[$label] = esc_html__( 'All', 'angio' );
    }

    foreach ($atts['taxes'] as $k => $t) {

        // Tax name  
        $temp_taxes[$count]['tax_name'] = $t['tax_name'];

        // IDS  
        if ( isset( $atts[$t['ids']] ) ) {
            $temp_taxes[$count]['ids'] = $atts[$t['ids']];
            unset( $atts[$t['ids']] );
        } else {
            $temp_taxes[$count]['ids'] = '';
        }

        // Slugs  
        if ( isset( $atts[$t['slugs']] ) ) {
            $temp_taxes[$count]['slugs'] = $atts[$t['slugs']];
            unset( $atts[$t['slugs']] );
        } else {
            $temp_taxes[$count]['slugs'] = '';
        }

        // Label  
        if ( isset( $atts[$t['label']] ) ) {
            $temp_taxes[$count]['label'] = $atts[$t['label']];
            unset( $atts[$t['label']] );
        } else {
            $temp_taxes[$count]['label'] = esc_html__( 'All', 'angio' );
        }

        $count++;

    }

    unset($atts['taxes']);

    // Set order  
    if ( isset( $atts['filters_order'] ) ) {
        $order = array_map( 'intval', explode(',', $atts['filters_order'] ) );
        $sorted_taxes = array();
        if ( is_array( $order ) ) {            
            foreach ( $order as $key => $value ) {
                if ( isset( $temp_taxes[$value] ) ) {
                    $sorted_taxes[] = $temp_taxes[$value];
                }
            }

            $temp_taxes = $sorted_taxes;
        }

        unset( $atts['filters_order'] );
    }


    // Set index  
    foreach ($temp_taxes as $key => $value) {
        $index = $value['tax_name'];
        $atts['taxonomies'][$index] = $value;

        if ( $multiple_filters === false ) {
            break;
        }
    }
    return $atts;

}
endif;


/* ==================================================
  Prepare WP Query 
  ver 1.1.0
================================================== */
if ( ! function_exists( 'angio_prepare_wp_query' ) ) :
function angio_prepare_wp_query( $atts = '', $paged = '' ) {

    if ( isset( $atts[0] ) ) {
        $atts = $atts[0];
    }

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_ids'            => '',
        'taxonomies'          => [],
        'tag_slugs'           => '',
        'sort_order'          => 'post_date',
        'limit'               => 8,
        'author_ids'          => '',
        'offset'              => '0',
        'posts_per_page'      => '',
        'post_type'           => 'post',
        'year'                => '',
        'monthnum'            => '',
        'day'                 => '',
        'ignore_sticky_posts' => 1,

    );

    // If $atts is not array 
    if ( ! is_array( $atts ) ) {
        return false;
    }
    
    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    extract( $atts, EXTR_PREFIX_SAME, 'query_arg' );

    // Make sure that offset is integer 
    $offset = (int)$offset;

    // Init WP query 
    $query_args = array(
        'post_type' => $post_type,
        'ignore_sticky_posts' => $ignore_sticky_posts,
        'post_status' => 'publish',
    );

    // Categories 
    if ( ! empty( $taxonomies ) ) {

        $k = 0;

        foreach ( $taxonomies as $t ) {

            // Skip Event type taxonomy  
            if ( isset( $event_type_tax ) && $t['tax_name'] === $event_type_tax ) {
                continue;
            }

            $tax_terms = [];
            $field_name = 'term_id';

            // IDS or Slugs 

            // Saved 
            if ( ! empty( $t['ids'] ) ) {
                $tax_terms = $t['ids'];
            } else if ( ! empty( $t['slugs'] ) ) {
                $field_name = 'slug';
                $tax_terms = $t['slugs'];
            }

            if ( ! is_array( $tax_terms ) ) {
                $tax_terms = explode( ',', $tax_terms );

            } 

            // From filter 
            if ( isset( $t['filter_ids'] ) && ! empty( $t['filter_ids'] ) ) {
                //$tax_terms = array_unique( array_merge( $tax_terms, $t['filter_ids'] ), SORT_REGULAR );
                $tax_terms = $t['filter_ids'];
            }


            // Simple Category (Blog)  
            if ( $post_type === 'post' && ! empty( $tax_terms ) ) {

                if ( $field_name === 'slug' ) {
                    $cat_slugs_a = $tax_terms;
                    $cat_ids_a = array();
                    foreach ( $cat_slugs_a as $slug ) {
                        if ( $slug[0] === '-'  ) {
                            $str = substr( $slug, 1 );
                            $is_minus = true;
                        } else {
                            $is_minus = false;
                        }
                        if ( get_category_by_slug( $slug ) ) {
                            $cat_obj = get_category_by_slug( $slug );
                            $cat_id = $cat_obj->term_id;
                            if ( $is_minus ) {
                                $cat_id = (-1 * abs( $cat_id ) );
                            }
                            $cat_ids_a[] = $cat_id;
                        }
                    }
                    if ( ! empty( $cat_ids_a ) ) {
                        $tax_terms = implode( ',', $cat_ids_a );
                    }

                 }

                $query_args['cat'] = $tax_terms;
                break;
            }

            if ( ! empty( $tax_terms ) ) {

                // Custom post type category  
                $query_args['tax_query'][$k] = array(
                    'taxonomy' => $t['tax_name'],
                    'field'    => $field_name,
                    'terms'    => $tax_terms,
                );
                
            }      

            $k++;

        }

    }


    if ( ! empty( $tag_slugs ) ) {
        $query_args['tag'] = $tag_slugs;
    }

    if ( ! empty( $author_ids ) ) {
        $query_args['author'] = $author_ids;
    }

    if ( ! empty( $year ) ) {
        $query_args['year'] = $year;
    }

    if ( ! empty( $monthnum ) ) {
        $query_args['monthnum'] = $monthnum;
    }

    if ( ! empty( $day ) ) {
        $query_args['day'] = $day;
    }

    if ( ! empty( $post_ids ) ) {

        $post_ids_a = explode ( ',', $post_ids );

        $post__in = array();
        $post__not_in = array();

        foreach ( $post_ids_a as $post_id ) {
            $post_id = trim( $post_id );

            if ( is_numeric( $post_id ) ) {
                if ( intval( $post_id ) < 0 ) {
                    $post__not_in[] = str_replace('-', '', $post_id);
                } else {
                    $post__in[] = $post_id;
                }
            }
        }

        if ( ! empty( $post__in ) ) {
            $query_args['post__in'] = $post__in;
            $query_args['orderby'] = 'post__in';
        }

        if ( ! empty( $post__not_in ) ) {
            $query_args['post__not_in'] = $post__not_in;
        }
    }

    switch ( $sort_order ) {
        
        case 'menu_order':
            $query_args['orderby'] = 'menu_order';
            $query_args['order'] = 'ASC';
            break;
        case 'oldest_posts':
            $query_args['order'] = 'ASC';
            break;
        case 'highest_rated':
            $query_args['meta_query'] = array(
                'relation' => 'AND',
                'has_review' => array(
                    'key' => '_has_reviews',
                    'value'   => true,
                ),
                'rating' => array(
                    'key' => '_rating',
                    'compare' => 'EXISTS',
                ), 
            );
            $query_args['orderby'] = array( 
                'rating' => 'DESC'
            );
            break;
        case 'rand':
            $query_args['orderby'] = 'rand';
            break;
        case 'title':
            $query_args['orderby'] = 'title';
            $query_args['order'] = 'ASC';
            break;
        case 'comment_count':
            $query_args['orderby'] = 'comment_count';
            $query_args['order'] = 'DESC';
            break;
        case 'rand_today':
            $query_args['orderby'] = 'rand';
            $query_args['year'] = date('Y');
            $query_args['monthnum'] = date('n');
            $query_args['day'] = date('j');
            break;
        case 'rand_week':
            $query_args['orderby'] = 'rand';
            $query_args['date_query'] = array(
                        'column' => 'post_date_gmt',
                        'after' => '1 week ago'
                        );
            break;

    }

    // Limit posts per page 
    if ( empty( $limit ) ) {
        $limit = -1;
    }
    $query_args['posts_per_page'] = $limit;

    // Pagination 
    if ( ! empty( $paged ) ) {
        $query_args['paged'] = $paged;
    } else {
        $query_args['paged'] = 1;
    }


    // Event Type 
    if ( isset( $event_type_tax ) ) {

        if ( !isset( $event_type ) ) {
            $event_type = 'future-events';
        }

        if ( $event_type === 'future-events' || $event_type === 'past-events' ) {

            // Set order 
            $order = $event_type === 'future-events' ? $order = 'ASC' : $order = 'DSC';

            if ( ! isset( $query_args['tax_query'] ) ) {
                $query_args['tax_query'] = array();
            }
            $query_args['tax_query']['relation'] = 'AND';

            array_push( $query_args['tax_query'], 
                array(
                   'taxonomy' => $event_type_tax,
                   'field'    => 'slug',
                   'terms'    => $event_type
                )
            );

            $query_args['orderby'] = 'meta_value';
            $query_args['order'] = $order;
            $query_args['meta_key'] = '_event_order';
            
        }

        if ( $event_type === 'all' ) {

            // Reset Query 
            $offset = 0;
            unset($query_args['post__in'],$query_args['post__not_in']);

            $future_tax = array(
                'relation' => 'AND',
                array(
                   'taxonomy' => $event_type_tax,
                   'field'    => 'slug',
                   'terms'    => 'future-events'
                )
            );

            $past_tax = array(
                'relation' => 'AND',
                array(
                   'taxonomy' => $event_type_tax,
                   'field'    => 'slug',
                   'terms'    => 'past-events'
                  )
            );

            if ( isset( $query_args['tax_query']  ) ) {
                array_push( $future_tax, $query_args['tax_query']);
                array_push( $past_tax, $query_args['tax_query']);
            }

            $future_events = get_posts( array(
                'post_type' => $post_type,
                'showposts' => -1,
                'tax_query' => $future_tax,
                'orderby' => 'meta_value',
                'meta_key' => '_event_order',
                'order' => 'ASC'
            ));

            // Past Events
            $past_events = get_posts(array(
                'post_type' => $post_type,
                'showposts' => -1,
                'tax_query' => $past_tax,
                'orderby' => 'meta_value',
                'meta_key' => '_event_order',
                'order' => 'DSC'
            ));

            $future_nr = count( $future_events );
            $past_nr = count( $past_events );

            // echo "Paged: Future events: $future_nr, Past events: $past_nr";

            $mergedposts = array_merge( $future_events, $past_events ); //combine queries

            $postids = array();
            foreach( $mergedposts as $item ) {
                $postids[] = $item->ID; //create a new query only of the post ids
            }
            $uniqueposts = array_unique( $postids ); //remove duplicate post ids

            $query_args['orderby'] = 'post__in';
            $query_args['post__in'] = $uniqueposts;

            // Remove Tax query
            if ( isset( $query_args['tax_query'] ) ) {
                unset($query_args['tax_query']);

            }
        
        }

    }

    // Offset 
    if ( $offset > 0 ) {

        if ( isset( $post__in ) && is_array( $post__in ) ) {
            $query_args['post__in'] = array_slice( $query_args['post__in'], $offset );
        } else {
            $fake_args = $query_args;
            $fake_args['posts_per_page'] = $offset;
            $fake_query = new WP_Query( $fake_args );
            $not_in_main_query = array();
            if ( $fake_query->have_posts() ) {
                while ( $fake_query->have_posts() ) {
                    $fake_query->the_post();
                    $not_in_main_query[] = get_the_ID();
                }
            } 
            // Restore original Post Data 
            wp_reset_postdata();
            
            if ( isset( $post__not_in ) && is_array( $post__not_in ) ) {
                $not_in_main_query = array_merge( $post__not_in, $not_in_main_query );
            }
            $query_args['post__not_in'] = $not_in_main_query;
        }

    }

    return $query_args;

}
endif;