<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            helpers.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* ==================================================
  Theme Title 
================================================== */
if ( ! function_exists( 'angio_theme_title' ) ) :
function angio_theme_title( $atts = [] ) {
	 if ( empty( $atts ) ) {
        return false;
    }

    $defaults = array( 
		'el'      => 'h1',
		'title'   => esc_html__( 'Default Title', 'angio'),
		'effect'  => 'console_typer',
		'data'    => [],
		'classes' => '',
    );
    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // FX Classes
   	$fx_classes = [
   		'console_typer' => 'is-waypoint autotype',
   		'opacity' => 'is-waypoint appear-opacity',
   		'slideup' => 'is-waypoint slide-text-up'
   	];
   	if ( isset( $fx_classes[$atts['effect']] )) {
   		$atts['classes'] .= ' ' . $fx_classes[$atts['effect']];
   	}

   	// Data attributes
   	$data_atts = '';
   	if ( empty( $atts['data'] ) === false ) {
   		$data_atts = '';

   		foreach ($atts['data'] as $name => $attr ) {
   			$data_atts .= ' data-' . $name . '="' . $attr . '"';
   		}

   	}

	$output = '<' . esc_attr($atts['el']) . ' class="  '. esc_attr($atts['classes']) .'" ' . $data_atts . '>';

		if ( $atts['effect'] === 'slideup' ) {
			$output .= '<span class="slide-text-up__text delay-01">' . wp_kses( $atts['title'], 'title' ) . '</span>' ;
		} else {
			$output .= wp_kses( $atts['title'], 'title' );
		} 

	
 
	$output .= '</' . esc_attr($atts['el']) . '>';

	return $output;
     
}
endif;


/* ==================================================
  Arrow Svg     
================================================== */
if ( ! function_exists( 'angio_svg_arrow' ) ) :
function angio_svg_arrow( $classes = '' ) {
     return '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 36 36" xml:space="preserve">
        <g>
            <line x1="18" y1="0" x2="18" y2="4"></line>
            <line x1="18" y1="7" x2="18" y2="19"></line>
            <polyline points="21.7,15.2 18,19.4 14.3,15.2   "></polyline>
        </g>
        <path d="M29.8,5.1c3.5,3.2,5.7,7.8,5.7,12.9c0,9.7-7.8,17.5-17.5,17.5S0.5,27.7,0.5,18c0-4.8,2-9.2,5.1-12.4"></path>
    </svg>';
}
endif;


/* ==================================================
  Share Buttons 
================================================== */
if ( ! function_exists( 'angio_share_buttons' ) ) :

/**
 * Show share buttons
 * @param  $post_id [Post ID]
 * @return string   [Buttons HTML code]
 */
function angio_share_buttons( $post_id ) {
    return '<span class="icon icon-share"></span>
            <a class="share-button fb-share-btn b-style-1" target="_blank" href="http://www.facebook.com/sharer.php?u=' . esc_url( get_permalink( $post_id ) ) . '">Fb</a>
            <a class="share-button twitter-share-btn b-style-1" target="_blank" href="http://twitter.com/share?url=' . esc_url( get_permalink( $post_id ) ) . '">Tw</a>
            <a class="share-button linkedin-share-btn b-style-1" target="_blank" href="https://www.linkedin.com/cws/share?url=' . esc_url( get_permalink( $post_id ) ) . '">Ln</a>';

}
endif;


/* ==================================================
  Socials
================================================== */ 
if ( ! function_exists( 'angio_social_list' ) ) :
function angio_social_list() {
  
    $output = '';
    $delay = 1;

    $socials = angio_get_option('socials', false);
    
    if ( $socials && is_array( $socials ) ) {
        $output .= '<ul class="socials__list">';

        // Get 
        foreach ($socials as $key => $social) {
            $output .= '<li class="trans-05 delay-0' . esc_attr( $key ) . '">';
            $output .= '<div class="magneto">';
            $output .= '<a href="' . esc_url( $social['link'] ) . '" class="socials__link social--' . esc_attr( $social['service'] ) . ' b-style-1">';
            $output .= '<span class="social__name social__name-' . esc_attr( $social['service'] ). '">' . esc_html( $social['service'] ) . '</span>';
            $output .= '</a>';
            $output .= '</div>';
            $output .= '</li>';
         
        }
    
     $output .= '</ul>';
    }

    return $output;
                
    
}
endif;


/* ==================================================
   KSES Filter
================================================== */
function angio_kses_allowed_html($tags, $context) {
  switch($context) {
    case 'rich_text': 
      $tags = array( 
        'a'      => array(
            'class'  => array(),
            'href'   => array(),
            'target' => array(), 
            'title'  => array()
        ),
        'img'      => array(
            'src'  => array(),
            'alt'   => array(),
            'class' => array(), 
        ),
        'b'      => array(),
        'strong' => array(),

      );
      return $tags;
    case 'title': 
      $tags = array( 
        'a'      => array(
            'class'  => array(),
            'href'   => array(),
            'target' => array(), 
            'title'  => array()
        ),
        'b'      => array(),
        'strong' => array(),
        'i'      => array(),
        'em'     => array(),
        'sup'    => array(),
      );
      return $tags;  
    default: 
      return $tags;
  }
}

add_filter( 'wp_kses_allowed_html', 'angio_kses_allowed_html', 10, 2);



/* ==================================================
  Show Loader 
================================================== */
if ( ! function_exists( 'angio_loader' ) ) :
function angio_loader() {

    $loader = '<div class="loader__content">';
    $loader .= '<div class="loader__inner">';
        $loader .= '<div class="loader__image">';
        $logo = get_template_directory_uri() . '/images/logo.svg';
        if ( angio_get_option( 'preloader_image', '' ) !== '' ) {
        	$loader .= '<img class="loader__custom-image" src="' . angio_get_image_src( 'preloader_image', 'full', $logo ) . '" alt="' . esc_attr__( 'Preloader Image', 'angio' ) . '">';
        } else {
        	$loader .= '<img src="' . angio_get_image_src( 'logo', 'full', $logo ) . '" alt="' . esc_attr__( 'Preloader Image', 'angio' ) . '">';
    	}
    	$loader .='<div class="loader__progress"></div>';
    	$loader .='<div class="loader__bytes"></div>';
        $loader .= '</div>';
    $loader .= '</div>'; // /inner
    $loader .= '</div>';
    if( has_filter('angio_wpal_change_loader') ) {
        $loader = apply_filters( 'angio_wpal_change_loader', $loader );
    }
    return '<div class="loader">' . angio_esc( $loader ) . '</div>';
}
endif;


/* ==================================================
  Get image
  ver 1.1.0
================================================== */
if ( ! function_exists( 'angio_get_image' ) ) :

function angio_get_image( $image_id, $thumb_size = 'thumbnail' ) {

    if ( wp_get_attachment_image_src( $image_id, $thumb_size ) ) {
        $image_src = wp_get_attachment_image_src( $image_id, $thumb_size );
        $image_src = $image_src[0];
        return $image_src;
    }    

    return false;
}
endif;


/* ==================================================
  Get post image
  ver 1.1.0
================================================== */
if ( ! function_exists( 'angio_get_post_image' ) ) :
function angio_get_post_image( $post_id, $thumb_size = 'thumbnail' ) {

    if ( has_post_thumbnail( $post_id ) ) {
        $image_id = get_post_thumbnail_id( $post_id );
        if ( wp_get_attachment_image_src( $image_id, $thumb_size ) ) {
            $image_src = wp_get_attachment_image_src( $image_id, $thumb_size );
            $image_src = $image_src[0];
            return $image_src;
        }   
    }
    return false;
}
endif;


/* ==================================================
  Get resize image
  ver 1.1.0
================================================== */
if ( ! function_exists( 'angio_resize_image' ) ) :
function angio_resize_image( $image_id, $width = 150, $height = 150, $crop = 'c' ) {

    if ( wp_get_attachment_image_src( $image_id, 'full' ) ) {
        $image_src = wp_get_attachment_image_src( $image_id, 'full' );
        $image_src = $image_src[0];
        if ( function_exists( 'angio_toolkit_image_resize' ) ) {
            $image_src = angio_toolkit_image_resize( $image_src, $width, $height, $crop );
        }
        return $image_src;
    }    
    return false;
}
endif;


/* ==================================================
  Get resize image
  ver 1.1.0
================================================== */
if ( ! function_exists( 'angio_resize_post_image' ) ) :
function angio_resize_post_image( $post_id, $width = 150, $height = 150, $crop = 'c' ) {

    if ( has_post_thumbnail( $post_id ) ) {
        $image_id = get_post_thumbnail_id( $post_id );
        if ( wp_get_attachment_image_src( $image_id, 'false' ) ) {
            $image_src = wp_get_attachment_image_src( $image_id, 'false' );
            $image_src = $image_src[0];
            if ( function_exists( 'angio_toolkit_image_resize' ) ) {
                $image_src = angio_toolkit_image_resize( $image_src, $width, $height, $crop );
            }
            return $image_src;
        }   
    }
    return false;
}
endif;


/* ==================================================
  Get taxonomies 
================================================== */
if ( ! function_exists( 'angio_get_taxonomies' ) ) :
function angio_get_taxonomies( $atts = array() ) {

    if ( empty( $atts ) ) {
        return false;
    }

    $defaults = array( 
        'id'             => null,
        'tax_name'       => 'category',
        'separator'      => '',
        'parent_classes' => '',
        'child_classes'  => '',
        'link'           => true,
        'limit'          => 200,
        'show_count'     => false
    );

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'tax' );

    $categories = get_the_terms( $id, $tax_name );
    $output = '';
    if ( ! empty( $categories ) ) {
        $count = 1;
        foreach( $categories as $category ) {
            if ( $link === true ) {
                $output .= '<a class="cat cat-' . esc_attr( $category->term_id ) . ' ' . esc_attr( $parent_classes ) . '" href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . esc_attr__( 'View posts from category', 'angio' ) . '"><span class="cat-inner ' . esc_attr( $child_classes ) . '">' . esc_html( $category->name ) . '</span></a>' . esc_attr ( $separator );
            } else {
                $output .= '<span class="cat cat-' . esc_attr( $category->term_id ) . ' ' . esc_attr( $parent_classes ) . '"><span class="cat-inner ' . esc_attr( $child_classes ) . '">' . esc_html( $category->name ) . '</span></span>' . esc_attr ( $separator );
            }
            if ( $limit !== -1 && $count === $limit ) {
                break;
            }
            $count++;
        } 
        if ( $show_count && count( $categories ) > $limit ) {

            $counts_nr = '<span class="cats-count">+' . esc_attr( count( $categories ) - $count ) . '</span>';
        } else {
            $counts_nr = '';
        }
        return trim( $output, $separator ) . $counts_nr;
    }
    return false;
}
endif;


/* ==================================================
  Comments List 
================================================== */
if ( ! function_exists( 'angio_comments' ) ) :
function angio_comments( $comment, $atts, $depth ) {

    $GLOBALS['comment'] = $comment; 
 
    ?>

    <!-- Comment -->
    <li id="li-comment-<?php comment_ID() ?>" <?php comment_class( 'theme_comment' ); ?>>
        <article id="comment-<?php comment_ID(); ?>">
            <div class="avatar-wrap">
                <?php echo get_avatar( $comment, '100' ); ?>
            </div>
            <div class="comment-meta">
                <h5 class="author"><?php comment_author_link(); ?></h5>
                <p class="date"><?php comment_date( ); ?> <span class="reply"><?php comment_reply_link( array_merge( $atts, array( 'reply_text' => esc_html__( 'Reply', 'angio'), 'depth' => $depth, 'max_depth' => $atts['max_depth'] ) ) ); ?></span></p>
            </div>
            <div class="comment-body">
                <?php comment_text(); ?>
                <?php if ( $comment->comment_approved === '0' ) : ?>
                <p class="message info"><?php esc_html_e( 'Your comment is awaiting moderation.', 'angio' ); ?></p>
                <?php endif; ?> 
            </div>
        </article>
<?php 
}
endif;


/* ==================================================
  Tag Cloud Filter 
================================================== */
if ( ! function_exists( 'angio_tag_cloud_filter' ) ) :
function angio_tag_cloud_filter( $atts = array() ) {
   $atts['smallest'] = 13;
   $atts['largest'] = 13;
   $atts['unit'] = 'px';
   return $atts;
}
add_filter( 'widget_tag_cloud_args', 'angio_tag_cloud_filter', 90 );
endif;

    
/* ==================================================
  WP Title
  Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view. 
================================================== */
if ( ! function_exists( 'angio_wp_title' ) ) :
function angio_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) {
        return $title;
    }

    // Add the site name.
    $title .= get_bloginfo( 'name', 'display' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) ) {
        $title = "$title $sep $site_description";
    }

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 ) {
        $title = esc_html( "$title $sep " . sprintf( esc_html__( 'Page %s', 'angio' ), max( $paged, $page ) ) );
    }

    return $title;
}
add_filter( 'wp_title', 'angio_wp_title', 10, 2 );
endif;


/* ==================================================
  Add Body Classes 
================================================== */
if ( ! function_exists( 'angio_body_class' ) ) :
function angio_body_class( $classes ) {

	// Hidden header
	$hidden_header = '';

	// Page Title
    $page_title = get_post_meta( get_the_ID(), '_page_title', true );
    if ( $page_title ) {
    	$classes[] = 'page-title-' . esc_html( $page_title );

    	if ( in_array( $page_title, ['fullscreen-parallax'], true ) ) {
    		$hidden_header = 'is-hidden-header';
    	}

    }

    // Fullscreen
    $fullscreen_class = 'no-fullscreen';
    $page_layout = get_post_meta( get_the_ID(), '_page', true );
    if ( is_page_template( array( 'template-albums-slider.php', 'template-wave.php', 'template-menu.php' ) ) ) {
        $page_layout = 'fullscreen';
    }

    // Hide footer
    if ( is_page_template( [ 'template-albums-slider.php', 'template-parallax-slider.php' ] ) ) {
    	$classes[] = 'no-footer';
    }
    
    if ( is_page() || is_single() ) {

        if ( in_array( $page_layout, ['fullscreen', 'fullscreen-horizontal', 'album-left', 'event1'], true ) ) {
            $fullscreen_class = 'is-fullscreen';
            $hidden_header = 'is-hidden-header';
        } else {
        	$fullscreen_class = 'no-fullscreen';
        }
    }
    $classes[] = $fullscreen_class;


    // AXloader
    if ( ! is_customize_preview() && angio_get_option( 'ajaxed', 'off' ) === 'on' ) {
        $classes[] = 'AXloader';

        // Preloader
        if ( angio_get_option( 'page_transition', 'off' ) === 'on' ) {
            $classes[] = 'is-page-transitions';
        } else {
            $classes[] = 'no-page-transitions';
        }
    } 

    // Scroll Mask
    $scroll_mask = get_post_meta( get_the_ID(), '_scroll_mask', true );
    $scroll_mask = ( $scroll_mask === 'off' ) ? false : true; 
    if ( $scroll_mask ) {
        $classes[] = 'is-scroll-mask';
    } else {
        $classes[] = 'no-scroll-mask';
    }

    // Hide Menu
    $hide_menu = get_post_meta( get_the_ID(), '_hide_menu', true );

     if ( $hide_menu === 'on' ) {
        $classes[] = 'no-main-menu';
    }
    
    // Smoothscroll
    if ( angio_get_option( 'smooth_scroll', 'off' ) === 'on' ) {
        $classes[] = 'is-smoothscroll';
    } else {
        $classes[] = 'no-smoothscroll';
    }

    // Hud
    if ( angio_get_option( 'hud', 'off' ) === 'on' ) {
        $classes[] = 'is-hud';
    } 

    // Scroll Animations
    if ( angio_get_option( 'scrollmagic', 'off' ) === 'on' ) {
        $classes[] = 'is-scroll-animations';
    } 

    // Cursor
    if ( angio_get_option( 'cursor_effects', 'off' ) === 'on' ) {
        $classes[] = 'is-cursor-effects';
    } else {
        $classes[] = 'no-cursor-effects';
    }

    // If tags, category...
    if ( is_tag() || is_archive() || is_tax() || is_category() || is_author() || is_404() || is_attachment() || is_search() ) {

    	$hidden_header = '';

    }

    // Hidden header
    if ( $hidden_header !== '' ) {
    	$classes[] = $hidden_header;
	}

    return $classes;
     
}
add_filter( 'body_class', 'angio_body_class' );
endif;




/* ==================================================
  Facebook Share Options 
================================================== */
if ( ! function_exists( 'angio_share_options' ) ) :
function angio_share_options() {
    global $wp_query; 

    if ( is_single() || is_page() ) { 

        $is_fb_sharing = get_post_meta( $wp_query->post->ID, '_fb_sharing', true );

        if ( isset( $is_fb_sharing  ) && $is_fb_sharing === true ) {
            
            // Video 
            $share_video = get_post_meta( $wp_query->post->ID, '_share_video', true );
            if ( isset( $share_video ) && $share_video !== '' ) {
                echo '<meta property="og:url" content="' . esc_attr( $share_video ) . '"/>' . "\n";     
            } else {
                echo '<meta property="og:url" content="' . esc_url( get_permalink( $wp_query->post->ID ) ) . '"/>' . "\n";
            }
            
            // Title 
            $share_title = get_post_meta( $wp_query->post->ID, '_share_title', true );
            if ( isset( $share_title ) && $share_title !== '' ) {
                 echo "\n" .'<meta property="og:title" content="' . esc_attr( $share_title ) . '"/>' . "\n";     
            } else {
                // Site name 
                echo "\n" .'<meta property="og:title" content="' . esc_attr( get_bloginfo('name') ) . '"/>' . "\n";     
            }

            // Description 
            $share_description = get_post_meta( $wp_query->post->ID, '_share_description', true );
            if ( isset( $share_description ) && $share_description !== '' ) {
                 echo "\n" .'<meta property="og:description" content="' . esc_attr( $share_description ) . '"/>' . "\n";     
            }

            // Image 
            $share_image = get_post_meta( $wp_query->post->ID, 'share_image', true );
            if ( isset( $share_image ) ) {
                $image_attributes = wp_get_attachment_image_src( $share_image, 'full' );
                if ( $image_attributes ) {
                    echo "\n" .'<meta property="og:image" content="' . esc_attr( $image_attributes[0] ) . '"/>' . "\n";
                }
            }
        }

    }
}
add_action( 'wp_head', 'angio_share_options' ); 
endif;


/* ==================================================
  WPML Language Selector 
================================================== */
if ( ! function_exists( 'angio_languages_list' ) ) :
function angio_languages_list( $id = '', $display ){
    if ( function_exists( 'icl_get_languages' ) ) {

        $languages = icl_get_languages( 'skip_missing=0&orderby=code' );
        if ( ! empty( $languages ) ) {
            if ( $id !== '' ) {
                echo '<div id="' . esc_attr($id) . '" class="lang-selector"><ul>';
            } else {
                 echo '<div class="lang-selector"><ul>';
            }
            foreach($languages as $l){
                echo '<li>';

                if ( $display === 'flags' ||  $display === 'language_codes_flags'  ) {
                    if ( $l['country_flag_url'] ) {
                        if ( ! $l[ 'active' ] ) {
                            echo '<a href="'. esc_url( $l['url'] ) . '">';
                        }
                        echo '<img src="'.esc_url($l['country_flag_url']).'" height="12" alt="'.esc_attr($l['language_code']).'" width="18" />';
                        if ( ! $l['active'] ) {
                            echo '</a>';
                         }
                     }

                }

                if ( $display !== 'flags' ) {
                    if ( ! $l[ 'active' ] ) {
                        echo '<a href="'. esc_url( $l['url'] ) . '">';
                    }
                    echo esc_attr( $l['language_code'] );

                    if ( ! $l['active'] ) {
                        echo '</a>';
                    }
                    echo '</li>';
                }
            }
            echo '</ul></div>';
        }
    }
}
endif;