<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            modules.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* ==================================================
  List Module 1 
  Simple list without images
================================================== */
if ( ! function_exists( 'angio_list_module' ) ) :
function angio_list_module( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'excerpt'       => true,
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );
        $page_title = get_post_meta( $post_id, '_page_title', true ); 

        $img = '<div class="image"><img src="' . esc_url($img_src_large) . '" class="mod__thumb" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></div>';
        $classes .= ' is-featured';
    } else {
        $img = '';
    }

    // Render module 
    $html .= '
        <div class="mod mod-list-1 is-waypoint ' . esc_attr( $classes ) . '">
                <div class="mod__inner ' . esc_attr( $posts_classes ) . '">
                 	<h2 class="mod__title fx-text-word is-waypoint">' . get_the_title( $post_id ) . '</h2>
                </div>
             <a class="mod__click fx-cursor" href="' . esc_url( get_permalink( $post_id ) ) . '" data-cursor-class="click"></a>
        </div>';
    return $html;
    
}
endif;


/* ==================================================
  News Index Module
================================================== */
if ( ! function_exists( 'angio_news_index_module' ) ) :
function angio_news_index_module( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'excerpt'       => true,
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    // Get taxonomies 
    if ( function_exists( 'angio_get_taxonomies' ) ) {
        $tax_args = array(
			'id'             => $post_id,
			'tax_name'       => 'category',
			'separator'      => '/',
			'parent_classes' => '',
			'child_classes'  => 'b-style-1',
			'link'           => true,
			'limit'          => 2,
			'show_count'     => false
        );
        $cats_html = angio_get_taxonomies( $tax_args );
    } else {
        $cats_html = '';
    }

    // Excerpt
    if ( $excerpt ) {
        if ( has_excerpt( $post_id ) ) {
            $excerpt = get_the_excerpt( $post_id );
        } else {

            ob_start();
            the_content();
            $content_output = ob_get_clean();
            $excerpt = $content_output;

        }
    } else {
        $excerpt = '';
    }

    // FX Classes
    $fx_classes = '';

   if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );
        $page_title = get_post_meta( $post_id, '_page_title', true ); 

        if ( in_array( $page_title, ['fullscreen-image'], true ) ) {
            $fx_classes = 'fx-load fx-load-fz fx-load-scroll-after';
        }

        $img = '<div class="image"><a href="' . esc_url( get_permalink( $post_id ) ) . '" class="" data-cursor-class="click"><img src="' . esc_url($img_src_large) . '" class="mod__thumb fx-load-img" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></a></div>';
        $bg = '<div class="mod__bg" style="background-image:url(' . esc_attr( $img_src_full ) . ');" ></div>';
        $classes .= ' is-featured';
    } else {
        $img = '';
        $bg = '';
    }

    // Render module 
    $html .= '
        <div class="mod mod-news-index ' . esc_attr( $classes ) . '">
                <div class="mod__inner ' . esc_attr( $posts_classes ) . '">
                	<div class="mod__date">' . esc_html( get_the_date( '', $post_id ) )  . '</div>
                	<h2 class="mod__title"><a href="' . esc_url( get_permalink( $post_id ) ) . '" >' . get_the_title( $post_id ) . '</a></h2>
                  	<div class="mod__cats"><div class="meta-cats__inner">' . angio_esc( $cats_html )  . '</div></div>
                    <div class="mod__img mod__cell">
                        ' . angio_esc( $img ) . '
                    </div>
                    <div class="mod__excerpt">
                        ' . angio_esc( $excerpt ) . '
                    </div>
                    <div class="mod__readmore">
                    	<div class="b-style-2-wrap">
                    		<span class="b-style-arrows">>>></span>
                            <a href="' . esc_url( get_permalink( $post_id ) ) . '" class="b-style-2 randomtype ' . esc_attr( $fx_classes ) . '">
                             	' . esc_html__( 'Read article', 'angio') . '
                            </a>
                        </div>
                    </div>

                </div>
        </div>';
    return $html;
    
}
endif;

/* ==================================================
  News Module 1 
  Small images list with background
================================================== */
if ( ! function_exists( 'angio_news_module1' ) ) :
function angio_news_module1( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'excerpt'       => true,
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    // Get taxonomies 
    if ( function_exists( 'angio_get_taxonomies' ) ) {
        $tax_args = array(
			'id'             => $post_id,
			'tax_name'       => 'category',
			'separator'      => '/',
			'parent_classes' => '',
			'child_classes'  => 'b-style-1',
			'link'           => true,
			'limit'          => 2,
			'show_count'     => false
        );
        $cats_html = angio_get_taxonomies( $tax_args );
    } else {
        $cats_html = '';
    }

    // Excerpt
    if ( $excerpt ) {
        if ( has_excerpt( $post_id ) ) {
            $excerpt = get_the_excerpt( $post_id );
        } else {

            ob_start();
            the_content();
            $content_output = ob_get_clean();
            $excerpt = $content_output;

        }
    } else {
        $excerpt = '';
    }

    // FX Classes
    $fx_classes = '';

    // ID
    $mod_id = 'mod-' . $post_id . uniqid();

   	if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );
        $page_title = get_post_meta( $post_id, '_page_title', true ); 

        if ( in_array( $page_title, ['fullscreen-image'], true ) ) {
            $fx_classes = 'fx-load fx-load-fz';
        }

        $img = '<div class="image"><a class="' . esc_attr( $fx_classes ) . '" href="' . esc_url( get_permalink( $post_id ) ) . '"><img src="' . esc_url($img_src_large) . '" id="' . esc_attr($mod_id) . '" class="mod__thumb fx-load-img" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></a></div>';
        $bg = '<div class="mod__bg" style="background-image:url(' . esc_attr( $img_src_full ) . ');" ></div>';
        $classes .= ' is-featured';
    } else {
        $img = '';
        $bg = '';
    }

    // Render module 
    $html .= '
        <div class="mod mod-news-1 is-waypoint appear-from-bottom delay-05 ' . esc_attr( $classes ) . '">
                <div class="mod__inner container container--narrow ' . esc_attr( $posts_classes ) . '">
                    <div class="mod__flex">
                        <div class="mod__cell mod__left">
                            <div class="mod__img mod__cell is-waypoint">
                                ' . angio_esc( $img ) . '
                            </div>
                        </div>
                        <div class="mod__cell mod__right">
                            <div class="mod__date ">' . esc_html( get_the_date( '', $post_id ) )  . '</div>
                            <h2 class="mod__title"><a class="' . esc_attr( $fx_classes ) . '" href="' . esc_url( get_permalink( $post_id ) ) . '" data-img-id="' . esc_attr($mod_id) . '">' . get_the_title( $post_id ) . '</a></h2>
                          	<div class="mod__cats"><div class="meta-cats__inner">' . angio_esc( $cats_html )  . '</div></div>
                            <div class="mod__excerpt">
                                ' . angio_esc( $excerpt ) . '
                            </div>
                            <div class="mod__readmore">
                            	<div class="b-style-2-wrap">
                            		<span class="b-style-arrows">>>></span>
	                                <a href="' . esc_url( get_permalink( $post_id ) ) . '" class="b-style-2 randomtype ' . esc_attr( $fx_classes ) . '" data-img-id="' . esc_attr($mod_id) . '">
	                                 	' . esc_html__( 'Read article', 'angio') . '
	                                </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                ' . angio_esc( $bg ) . '
             
        </div>';
    return $html;
    
}
endif;


/* ==================================================
  News Module 2 
  Big Images List
================================================== */
if ( ! function_exists( 'angio_news_module2' ) ) :
function angio_news_module2( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    // Get taxonomies 
    if ( function_exists( 'angio_get_taxonomies' ) ) {
        $tax_args = array(
           	'id'             => $post_id,
			'tax_name'       => 'category',
			'separator'      => '/',
			'parent_classes' => '',
			'child_classes'  => 'b-style-1',
			'link'           => true,
			'limit'          => 2,
			'show_count'     => false
        );
        $cats_html = angio_get_taxonomies( $tax_args );
    } else {
        $cats_html = '';
    }

    // ID
    $mod_id = 'mod-' . $post_id . uniqid();

    if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );
        $page_title = get_post_meta( $post_id, '_page_title', true ); 

        // FX Classes
        $fx_classes = '';

        if ( in_array( $page_title, ['fullscreen-image'], true ) ) {
            $fx_classes = 'fx-load fx-load-fz';
        }

        $img = '
            <div class="scaleimage">
                <a href="' . esc_url( get_permalink( $post_id ) ) . '" class="fx-cursor ' . esc_attr( $fx_classes ) . '" data-cursor-class="click" data-img-id="' . esc_attr($mod_id) . '">
                    <div class="img">
                        <picture>
                            <source media="(max-width:768px)" srcset="' . esc_url( $img_src_large ) . '">
                            <img id="' . esc_attr($mod_id) . '" src="' . esc_url( $img_src_full ) . '" alt="' . esc_attr__( 'Post Image', 'angio' ) . '" class="fx-load-img">
                        </picture>
                    </div>
                </a>
            </div>';
        $classes .= ' is-featured';
    } else {
        $img = '';
        $bg = '';
        $fx_classes = '';
    }

    // Render module 
    $html .= '
        <div class="mod mod-news-2 is-waypoint appear-from-bottom delay-05 ' . esc_attr( $classes ) . '">
            <div class="mod__inner ' . esc_attr( $posts_classes ) . '">
                <div class="mod__top">
                    <div class="mod__meta">
                        <div class="mod__date">' . esc_html( get_the_date( '', $post_id ) )  . '</div>
                    </div>
                    <h2 class="mod__title"><a href="' . esc_url( get_permalink( $post_id ) ) . '" class="' . esc_attr( $fx_classes ) . '" data-img-id="' . esc_attr($mod_id) . '">' .  get_the_title( $post_id ) . '</a></h2>
                     <div class="mod__meta">
                        <div class="mod__cats"><div class="meta-cats__inner">' . angio_esc( $cats_html )  . '</div></div>
                    </div>
                </div>
                <div class="mod__img mod__img--extend">
                    ' . angio_esc( $img ) . '
                </div>
            </div>
        </div>';
    return $html;
    
}
endif;


/* ==================================================
  News Module 3
  Grid
================================================== */
if ( ! function_exists( 'angio_news_module3' ) ) :
function angio_news_module3( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'excerpt'       => true,
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    // Get taxonomies 
    if ( function_exists( 'angio_get_taxonomies' ) ) {
        $tax_args = array(
            'id'             => $post_id,
            'tax_name'       => 'category',
            'parent_classes' => '',
            'separator'      => '/',
            'link'           => false,
            'limit'          => 2,
            'show_count'     => false
        );
        $cats_html = angio_get_taxonomies( $tax_args );
    } else {
        $cats_html = '';
    }

    // FX Classes
    $fx_classes = '';

   if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );
        $page_title = get_post_meta( $post_id, '_page_title', true ); 

        if ( in_array( $page_title, ['fullscreen-image'], true ) ) {
            $fx_classes = 'fx-load fx-load-fz';
        }

        $img = '<div class="image"><img src="' . esc_url($img_src_large) . '" class="mod__thumb fx-load-img" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></div>';
        $classes .= ' is-featured';
    } else {
        $img = '';
        $bg = '';
    }

    // Render module 
    $html .= '
        <div class="mod mod-news-3 is-waypoint appear-from-bottom waypoint-delay ' . esc_attr( $classes ) . '">
                <div class="mod__inner ' . esc_attr( $posts_classes ) . '">
                    <div class="mod__float">
                	 	<div class="mod__meta">
	                        <div class="mod__date">' . esc_html( get_the_date( '', $post_id ) )  . '</div>
	                    </div>
	                    <h2 class="mod__title">' .  get_the_title( $post_id ) . '</h2>
                     	<div class="mod__meta mod__meta-cats">
	                        <div class="mod__cats">' . angio_esc( $cats_html )  . '</div>
	                    </div>
                    </div>

                 	<div class="mod__img">
                        ' . angio_esc( $img ) . '
                    </div>
                    <a class="mod__click fx-cursor ' . esc_attr( $fx_classes ) . '" href="' . esc_url( get_permalink( $post_id ) ) . '" data-cursor-class="click"></a>
                </div>
        </div>';
    return $html;
    
}
endif;



/* ==================================================
  Event Module 1 (List)
================================================== */
if ( ! function_exists( 'angio_event_module1' ) ) :
function angio_event_module1( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'permalink'     => '#',
        'title'         => '',
        'posts_classes' => '',
        'classes'       => ''
    );


    // HTML variable 
    $html = '';

    // If $atts is not array 
    if ( ! is_array( $atts ) ) {
        return false;
    }
    
    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );
    
    if ( ! $post_id ) {
        return;
    }
    // Event Date 
    $event_time_start = get_post_meta( $post_id, '_event_time_start', true );
    $event_date_start = get_post_meta( $post_id, '_event_date_start', true );
    $event_date_start = strtotime( $event_date_start );
    $event_date_end = strtotime( get_post_meta( $post_id, '_event_date_end', true ) );

    // Event data
    $data = get_post_meta( $post_id, '_event_detail', true );

    $location = '';
    if ( isset( $data['venue'] ) && $data['venue']  !== '' ) {
        $location = $data['venue'];
    }

    // Render module 
    $html .= '
        <div class="mod mod-event-1 mod-event-list is-waypoint ' . esc_attr( $classes ) . '">
            <article class="mod__inner waypoint-delay ' . esc_attr( $posts_classes ) . '">
                <a class="mod__click fx-cursor fx-hover-image" href="' . esc_url( get_permalink( $post_id ) ) . '" data-cursor-class="hover-img">';

                    if ( angio_resize_post_image( $post_id ) ) {
                        $img_src = angio_resize_post_image( $post_id, 200, 280, 'c' );
                        $html .= '<img src="' . esc_url( $img_src ) . '" class="mod__thumb fx-hover-image__src" alt="' . esc_attr__( 'Post Image', 'angio' ) . '">';
                    }

                    $html .= '
                    <div class="mod__event-content">
	                    <div class="mod__event-date">
	                    	<span class="mod__event-day">' . date_i18n( 'd', $event_date_start ) . '</span>
	                    	<div class="mod__event-date-inner">
		                    	<span class="mod__event-month">' . date_i18n( 'M', $event_date_start ) . '</span>
		                    	<span class="mod__event-year">' . date_i18n( 'Y', $event_date_start ) . '</span>
	                    	</div>
	                    </div>
	                    <div class="mod__event-title">
	                   		<h2 class="mod__event-name">' . angio_esc( $title ) . ' </h2>
	                    	<div class="mod__event-location">' . angio_esc( $location ) . '</div>
	                    </div>
                    </div>
                </a>
            </article>
        </div>
    ';

    return $html;
}
endif;


/* ==================================================
  Event Module 2 (Grid)
================================================== */
if ( ! function_exists( 'angio_event_module2' ) ) :
function angio_event_module2( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'thumb_size'    => 'full',
        'permalink'     => '#',
        'excerpt'       => true,
        'posts_classes' => '',
        'classes'       => '',
        'date_format'	=> angio_get_option('event_date_format', 'd M Y')
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

   	// Event Date 
    $event_time_start = get_post_meta( $post_id, '_event_time_start', true );
    $event_date_start = get_post_meta( $post_id, '_event_date_start', true );
    $event_date_start = strtotime( $event_date_start );
    $event_date_end = strtotime( get_post_meta( $post_id, '_event_date_end', true ) );

    // Event data
    $data = get_post_meta( $post_id, '_event_detail', true );

    $location = '';
    if ( isset( $data['venue'] ) && $data['venue']  !== '' ) {
        $location = $data['venue'];
    }

  
   	if ( angio_get_post_image( $post_id ) ) {
        $img_src_large = angio_get_post_image( $post_id, 'large' );
        $img_src_full = angio_get_post_image( $post_id, 'full' );

        $img = '<div class="image"><img src="' . esc_url($img_src_large) . '" class="mod__thumb" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></div>';
        $classes .= ' is-featured';
    } else {
    	$img = '<div class="image"><img src="' . esc_url(get_template_directory_uri() . '/images/dummy-cover-560x680.png') . '" class="mod__thumb" alt="' . esc_attr__( 'Post Image', 'angio' ) . '"></div>';
    	$classes = ' no-image';
    }

    // Render module 
    $html .= '
        <div class="mod mod-event-2 is-waypoint appear-from-bottom waypoint-delay ' . esc_attr( $classes ) . '">
                <div class="mod__inner ' . esc_attr( $posts_classes ) . '">
	          		<div class="mod__event-details">
	                    <h2 class="mod__title">' .  get_the_title( $post_id ) . '</h2>
	                    <div class="mod__event-date">
                    	' . date_i18n( $date_format, $event_date_start ) . '
                    	</div>
                    </div>
                 	<div class="mod__img">
                        ' . angio_esc( $img ) . '
                    </div>
                    <a class="mod__click fx-cursor" href="' . esc_url( get_permalink( $post_id ) ) . '" data-cursor-class="click"></a>
                </div>
        </div>';
    return $html;
    
}
endif;


/* ==================================================
  Album Module 1  
================================================== */
if ( ! function_exists( 'angio_album_module1' ) ) :
function angio_album_module1( $atts = array() ) {

    // The defaults will be overridden if set in $atts 
    $defaults = array( 
        'post_id'       => null,
        'posts_classes' => '',
        'classes'       => ''
    );

    // If $atts is not array 
    if ( ! is_array( $atts ) || ! isset( $atts['post_id'] ) || $atts['post_id'] === null ) {
        return false;
    }

    // Set default arguments 
    $atts = array_merge( $defaults, $atts );

    // Import variables into the current symbol table from an array 
    extract( $atts, EXTR_PREFIX_SAME, 'module' );

    // HTML variable 
    $html = '';

    // ID
    $mod_id = 'mod-' . $post_id . uniqid();

    if ( angio_get_post_image( $post_id ) ) {
        $img_src = angio_resize_post_image( $post_id, 650, 650, 'c' );
        $page = get_post_meta( $post_id, '_page', true ); 

        // FX Classes
        $fx_classes = '';
        $thumb_classes ="is-image";

        // If page has set layout with album image cover, add fx classes
        if ( in_array( $page, ['album-left'], true ) ) {
            $fx_classes = 'fx-load fx-load-fi';
        }

        // If Album has Elementor widgets with album cover, add fx classes
        if ( function_exists('angio_toolkit_page_has_el_widget') ) {

        	if ( angio_toolkit_page_has_el_widget($post_id, 'angio_album_cover') || angio_toolkit_page_has_el_widget($post_id, 'angio_album_player') );
        		
        		$fx_classes = 'fx-load fx-load-fi';

        } 

        $img = $img_src;
     	$img_html = '<img id="' . esc_attr($mod_id) . '" src="' . esc_url($img_src) . '" class="invisible fx-load-img" alt="' . esc_attr__( 'Album Cover', 'angio' ) . '">';
    } else {
    	$img = false;
    	$thumb_classes ="no-image";
    	$fx_classes = '';
    	$img_html = '<img src="' . esc_url(get_template_directory_uri() . '/images/dummy-cover-650x650.png') . '" class="invisible" alt="' . esc_attr__( 'Album Cover', 'angio' ) . '">';
    }

    // ID
    // 
 	$random_id = 'id-' . $post_id . '-' . rand(10000 , 99999);  

    // Render module 
    $html .= '
        <div id="' . esc_attr( $random_id ) . '" class="mod mod-album-1 ' . esc_attr( $classes ) . '">
            <div class="gthumb gthumb--style-2 randomtype is-waypoint appear-from-bottom waypoint-delay ' . esc_attr( $thumb_classes ) . ' ' . esc_attr( $posts_classes ) . '">
             	<div class="gthumb__images">
             		<div class="gthumb__img" style="background-image: url(' . esc_url( $img ) . ')"></div>
             		<div class="gthumb__img clone" style="background-image: url(' . esc_url( $img ) . ')"></div>
             		<div class="gthumb__img clone" style="background-image: url(' . esc_url( $img ) . ')"></div>
             		<div class="gthumb__img clone" style="background-image: url(' . esc_url( $img ) . ')"></div>
             		<div class="gthumb__img clone" style="background-image: url(' . esc_url( $img ) . ')"></div>
             	</div>
             	<div class="gthumb__desc">
             		<div class="gthumb__title randomtype__text">' . get_the_title( $post_id ) . '</div>
             	</div>
	            <a data-mod-id="' . esc_attr( $random_id ) . '" href="' . esc_url( get_permalink( $post_id ) ) . '" class="gthumb__click fx-cursor ' . esc_attr( $fx_classes ) . '" data-cursor-class="click" data-img-id="' . esc_attr($mod_id) . '">
	            </a>
	            ' . angio_esc( $img_html ) . '
            </div>
        </div>';
    return $html;
    
}
endif;