<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            template-tags.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/* ==================================================
  Get Paged
================================================== */
if ( ! function_exists( 'angio_get_paged' ) ) :
function angio_get_paged() {
	global $paged;
	return $paged;
}
endif;


/* ==================================================
  Loop Pagination 
================================================== */
if ( ! function_exists( 'angio_paging_nav' ) ) :
function angio_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'      => $pagenum_link,
		'format'    => $format,
		'total'     => $GLOBALS['wp_query']->max_num_pages,
		'current'   => $paged,
		'mid_size'  => 1,
		'prev_next' => false,
		'add_args'  => array_map( 'urlencode', $query_args ),
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation">
		<div class="pagination loop-pagination">
			<?php 
			echo paginate_links( array(
				'base'      => $pagenum_link,
				'format'    => $format,
				'total'     => $GLOBALS['wp_query']->max_num_pages,
				'current'   => $paged,
				'mid_size'  => 1,
				'prev_next' => false,
				'add_args'  => array_map( 'urlencode', $query_args ),
			) );

			?>
		</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
}
endif;


/* ==================================================
  Post Pagination
  Display navigation to next/previous post when applicable. 
================================================== */
if ( ! function_exists( 'angio_post_nav' ) ) :
function angio_post_nav() {
	global $post;

	$output = '';
	// Don't print empty markup if there's nowhere to navigate. 
	$previous  = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next      = get_adjacent_post( false, '', false );
	$post_type = get_post_type( $post->ID );

	if ( ! $next && ! $previous ) {
		echo '<nav class="navigation post-navigation empty"></nav>';
		return;
	}

	$next_link = get_adjacent_post( false,'',false );          
	$prev_link = get_adjacent_post( false,'',true ); 

	if ( $next_link ) {
		$next_link = $next_link->ID;
	} else {
		$next_link = false;
	}
	if ( $prev_link ) {
		$prev_link = $prev_link->ID;
	} else {
		$prev_link = false;
	}

	// TPL
	$next_post_tpl = '
		<a href="' . esc_url( get_permalink( $next_link ) ) . '" class="next-link nav-direction b-style-3">
            <span class="g" data-g="' . esc_html__( 'Next', 'angio' ) . '">' . esc_html__( 'Next', 'angio' ) . '</span>
	 	</a>';
	$prev_post_tpl = '
			<a href="' . esc_url( get_permalink( $prev_link ) ) . '" class="prev-link nav-direction b-style-3">
                <span class="g" data-g="' . esc_html__( 'Prev', 'angio' ) . '">' . esc_html__( 'Prev', 'angio' ) . '</span>
			</a>';
	$empty_post_tpl = '<div class="post-nav-inner link-empty"></div>';


	?>
	<?php
	if ( is_attachment() ) {
		$output .= '<div class="container"><div class="attachment-post-link">';
		$output .= get_previous_post_link( '%link', '<div class="meta-nav">' . esc_html__( 'Published In', 'angio' ) . '</div>' . esc_html__( '%title', 'angio' ) );
		$output .= '</div></div>';
		$output .= '<nav class="navigation post-navigation empty"></nav>';
	} else {
		$output .= '<nav class="navigation post-navigation"> <div class="nav-links">';
		
			if ( empty( $prev_link ) && $next_link ) {
				$output .= angio_esc( $empty_post_tpl );
			 	$output .= angio_esc( $next_post_tpl );
			} else if ( $prev_link && empty( $next_link ) ) {
			 	$output .= angio_esc( $prev_post_tpl );
				$output .= angio_esc( $empty_post_tpl );
			} else if ( $prev_link && $next_link  ) {
			 	$output .= angio_esc( $prev_post_tpl );
			 	$output .= angio_esc( $next_post_tpl );
			}
		
		$output .= '</div></nav>';
	}

	return $output;
	
}
endif;


/* ----------------------------------------------------------------------
	POST NAVIGATION WITH CUSTOM ORDER
	Display navigation to next/previous post with custom order for special CP.
/* ---------------------------------------------------------------------- */
if ( ! function_exists( 'angio_custom_post_nav' ) ) :
function angio_custom_post_nav() {
	global $post;

	if ( isset( $post ) ) {
		$backup = $post;
	}

	$output = '';
	$post_type = get_post_type($post->ID);
	$id = $post->ID;
	$count = 0;
	$prev_id = '';
	$next_id = '';
	$posts = array();
	

	if ( $post_type === 'angio_gallery' || $post_type === 'angio_albums' || $post_type === 'angio_artists' || $post_type === 'angio_events' || $post_type = 'angio_videos'  ) {

		// Music
		if ( $post_type === 'angio_albums' ) {
			
			$args = array(
				'post_type' => 'angio_albums',
				'showposts'=> '-1'
			);
		
			$args['orderby'] = 'menu_order';
			$args['order'] = 'ASC';

		}

		// Artist
		if ( $post_type === 'angio_artists' ) {
			
			$args = array(
				'post_type' => 'angio_artists',
				'showposts'=> '-1'
			);
		
			$args['orderby'] = 'menu_order';
			$args['order'] = 'ASC';
		}

		// Gallery
		if ( $post_type === 'angio_gallery' ) {
			
			$args = array(
				'post_type' => 'angio_gallery',
				'showposts'=> '-1'
			);

		}

		// Videos
		if ( $post_type === 'angio_videos' ) {
			
			$args = array(
				'post_type' => 'angio_videos',
				'showposts'=> '-1'
			);
		
			$args['orderby'] = 'menu_order';
			$args['order'] = 'ASC';

		}

		// Events
		if ( $post_type === 'angio_events' ) {
			if ( is_object_in_term( $post->ID, 'angio_event_type', 'future-events' ) ) {
				$event_type = 'future-events';
			} else {
				$event_type = 'past-events';
			}
			$order = $event_type === 'future-events' ? $order = 'ASC' : $order = 'DSC';
			$args = array(
				'post_type' => 'angio_events',
				'tax_query' => 
					array(
						array(
						'taxonomy' => 'angio_event_type',
						'field' => 'slug',
						'terms' => $event_type
						)
					),
				'showposts'=> '-1',
				'orderby' => 'meta_value',
				'meta_key' => '_event_date_start',
				'order' => $order
			);

		}

		// Nav loop
		$nav_query = new WP_Query();
		$nav_query->query( $args );
		if ( $nav_query->have_posts() )	{
			while ( $nav_query->have_posts() ) {
				$nav_query->the_post();
				$posts[] = get_the_id();
				if ( $count === 1 ) break;
				if ( $id === get_the_id() ) $count++;
			}
			$current = array_search( $id, $posts );

			$next_post_thumb = '';
			$prev_post_thumb = '';

			// Check IDs
			if ( isset( $posts[$current+1] ) ) {
				$next_id = $posts[$current+1];
			}
			if ( isset( $posts[$current-1] ) ) {
				$prev_id = $posts[$current-1];
			}


			// Check ID
			if ( $next_id ) {
				$next_id = $next_id;
			} else {
				$next_id = false;
			}
			if ( $prev_id ) {
				$prev_id = $prev_id;
			} else {
				$prev_id = false;
			}

			// TPL
			$next_post_tpl = '
				 <a href="' . esc_url( get_permalink( $next_id ) ) . '" class="next-link nav-direction b-style-3">
		            <span class="g" data-g="' . esc_html__( 'Next', 'angio' ) . '">' . esc_html__( 'Next', 'angio' ) . '</span>
			 	</a>';

			$prev_post_tpl = '
				<a href="' . esc_url( get_permalink( $prev_id ) ) . '" class="prev-link nav-direction b-style-3">
	                <span class="g" data-g="' . esc_html__( 'Prev', 'angio' ) . '">' . esc_html__( 'Prev', 'angio' ) . '</span>
				</a>';
			$empty_post_tpl = '<div class="post-nav-inner link-empty"></div>';

			// Display nav
			$output .= '
			<nav class="navigation post-navigation">
			<div class="nav-links">';
				
				if ( empty( $prev_id ) && $next_id ) {
					$output .= angio_esc( $empty_post_tpl );
				 	$output .= angio_esc( $next_post_tpl );
				} else if ( $prev_id && empty( $next_id ) ) {
				 	$output .= angio_esc( $prev_post_tpl );
					$output .= angio_esc( $empty_post_tpl );
				} else if ( $prev_id && $next_id  ) {
				 	$output .= angio_esc( $prev_post_tpl );
				 	$output .= angio_esc( $next_post_tpl );
				}
		
			$output .= '</div></nav>';
		}


		if ( isset( $post ) ) {
			$post = $backup;
		}
		
		return $output;
	} else {
		return false;
	}
}
endif;