<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            page.php
 * @package angio
 * @since 1.0.0
 */

get_header();

//////////////
// SET OPTS //
//////////////

// Page layout
// default, fullscreen
$page = get_post_meta( get_the_ID(), '_page', true );
$page = ( $page !== '' ? $page : angio_get_option( 'post_def_page', 'default' ) );

// Content 
$content = get_post_meta( get_the_ID(), '_content', true );
$content = ( $content !== '' ? $content : angio_get_option( 'event_def_content', 'default' ) );

// Title
$page_title = get_post_meta( get_the_ID(), '_page_title', true );
$page_title = ( $page_title !== '' ? $page_title : angio_get_option( 'post_def_page_title', 'simple' ) );


////////////
// LAYOUT //
////////////
$container_classes = array('container', 'container--narrow');
if ( $content === 'wide') {
	$container_classes = array('container');
} else if ( $content === 'fullwidth') {
	$container_classes = array('container', 'container--full');
} else if ( $content === 'elementor' ) {
	$container_classes = array('container--builder');
}


//////////////////////
// CUSTOM VARIABLES //
//////////////////////
$custom_vars = array(
	'page_title' => $page_title,
	'container_classes' => $container_classes,
	'article_classes' => ['post-content__article', 'is-waypoint', 'appear-from-bottom'],
	'show_content_footer' => false,
);

set_query_var( 'angio_vars', $custom_vars );

//////////////
// BG MUSIC //
//////////////
if ( function_exists( 'angio_toolkit_get_audio' ) && angio_get_option( 'background_player', 'off' ) === 'on' ) {
	$track_id = get_post_meta( get_the_ID(), '_track_id', true );
	$track_ids = get_post_meta( get_the_ID(), '_tracks_ids', true );
    $tracks = angio_toolkit_get_audio( $track_id, $track_ids );

    if ( $tracks ) {
    	echo '<div class="rp-page-audio" data-audio="' . esc_url( $tracks[0]['url'] ) . '"></div>';
    }

}


/////////////
// CONTENT //
/////////////

// Fullscreen
if ( $page === 'fullscreen' ) {
	get_template_part( 'partials/content', 'fullscreen' ); 
}

// Vertical Scroll
if ( $page === 'default' ) {

	if ( in_array( $content, ['default','wide','fullwidth','elementor'], true ) ) {
	
		// Default
		get_template_part( 'partials/content', '' ); 

	} 
}
 

////////////
// FOOTER //
////////////
get_footer();