<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            content.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

///////////////////////
// CONTENT VARIABLES //
///////////////////////
$render = 'content';
$show_content_footer = true;
$show_nav = true;
$show_comments = true;
$post_type = get_post_type( get_the_ID() );
$page_title = 'empty';


////////////
// LAYOUT //
////////////
$content = get_post_meta( get_the_ID(), '_content', true );
$content = ( $content !== '' ? $content : angio_get_option( 'post_def_layout', 'default' ) );
$content_classes = array(
	'content',
);
$container_classes = array(
	'container'
);
if ( $content === 'default' ) {
	array_push( $content_classes, 'content--layout-default' );
	$container_classes[] = 'container--narrow';
} else if ( $content === 'fullwidth' ) {
	unset( $container_classes );
	$container_classes[] = 'container--full';
} else if ( $content === 'elementor' ) {
	unset( $container_classes, $content_classes );
	$content_classes[] = 'content--builder';
	$container_classes[] = 'container--builder';
}

$article_classes = array('post-content__article');

/////////////
// SIDEBAR //
/////////////
$sidebar_pos = get_post_meta( get_the_ID(), '_sidebar_position', true ); 
$sidebar_pos = ( ! isset( $sidebar_pos ) || $sidebar_pos === '' ) ? angio_get_option( 'album_def_sidebar_pos', 'disabled' ) : $sidebar_pos;


////////////////
// BACKGROUND //
////////////////
if ( ! empty( get_post_meta( get_the_ID(), '_image_vertical_bg', true ) ) ) {
	$image_bg = get_post_meta( get_the_ID(), '_image_vertical_bg', true ); 
    $image_id = $image_bg;
    $img_src_full = wp_get_attachment_image_src( $image_id, 'full' );
    $img_src_full = $img_src_full[0];
    $img_src_large = wp_get_attachment_image_src( $image_id, 'large' );
	$img_src_large = $img_src_large[0];
	
	$bg_style = get_post_meta( get_the_ID(), '_vertical_bg_style', true );
	$bg_style = (!empty($bg_style)) ? $bg_style : 'fixed';
} else {
	$image_bg = false;
	$img_src_full = false;
	$img_src_large = false;
	$bg_style = 'none';
}


////////////////////
// PAGE VARIABLES //
////////////////////
if ( null !== get_query_var( 'angio_vars' ) ) {
	$opts = get_query_var( 'angio_vars' );

	$page_title =  (isset($opts['page_title'])) ? $opts['page_title'] : $page_title;
	$render = (isset($opts['render'])) ? $opts['render'] : $render;
	$content_classes = (isset($opts['content_classes'])) ? $opts['content_classes'] : $content_classes;
	$container_classes = (isset($opts['container_classes'])) ? $opts['container_classes'] : $container_classes;
	$article_classes = (isset($opts['article_classes'])) ? $opts['article_classes'] : $article_classes;
	$show_content_footer = (isset($opts['show_content_footer'])) ? $opts['show_content_footer'] : $show_content_footer;
	$show_nav = (isset($opts['show_nav'])) ? $opts['show_nav'] : $show_nav;
	$show_comments = (isset($opts['show_comments'])) ? $opts['show_comments'] : $show_comments;
	$sidebar_pos =  (isset($opts['sidebar_pos'])) ? $opts['sidebar_pos'] : $sidebar_pos;
};


////////////////////////
// CONTENT BACKGROUND //
////////////////////////
if ( $image_bg && $bg_style === 'fixed' ) : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>" data-app-bg="<?php echo esc_attr($img_src_full ) ?>">
<?php elseif ( $image_bg && $bg_style === 'scroll' ) : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?> content-bg" style="background-image:url(<?php echo esc_attr($img_src_full ) ?>)">
<?php else : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>">
<?php endif; ?>

	<?php 

	///////////
	// TITLE //
	///////////
	get_template_part( 'partials/title', $page_title);

 	?>

	<div class="<?php echo esc_attr( $post_type ) ?>-content">
		<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>">

			<article id="post-<?php the_ID(); ?>" <?php post_class( implode(' ', $article_classes ) ); ?>>

				<?php 
				////////////
				// RENDER //
				////////////
				get_template_part( 'partials/render', $render );  ?>
				
				<?php 
				/////////////////
				// POST FOOTER //
				/////////////////
				?>
				<?php if ( $show_content_footer === true ) : ?>
				<div class="post-footer">
					<div class="share">
						<?php 
							if ( angio_get_option('display_share_buttons', 'off' ) === 'on' && function_exists('angio_share_buttons') ) {
								echo angio_share_buttons($wp_query->post->ID);
							}
						 ?>
					</div>
					<?php // Tags
						the_tags( '<div class="meta-tags"><span class="icon icon-tag"></span>', ' ', '</div>' );
					?>
				</div>
				<?php endif ?>

				<?php
				/////////////////////
				// POST NAVIGATION //
				/////////////////////
				if ( $show_nav === true ) {
					if ( get_post_type( get_the_ID() ) === 'post' ) {
						if ( function_exists( 'angio_post_nav' ) ) {
							echo angio_post_nav();
						} else {
							posts_nav_link( ' &#183; ', esc_html_e( 'previous page', 'angio' ), esc_html_e( 'next page', 'angio' ) );
						}
					} else {
						if ( function_exists( 'angio_custom_post_nav' ) ) {
							echo angio_custom_post_nav();
						} else {
							posts_nav_link( ' &#183; ', esc_html_e( 'previous page', 'angio' ), esc_html_e( 'next page', 'angio' ) );
						}
					}
				}
				?>
				
			</article>  <!-- .article -->
		</div>
    </div> <!-- .container -->

    <?php 
    //////////////
    // COMMENTS //
    //////////////
 	?>
 	<?php 
 	if ( $show_comments ) :
	 	if ( comments_open() || get_comments_number() ) : ?>
	    <div class="comments container container--narrow">
				<?php
				// If comments are open or we have at least one comment, load up the comment template.
				$disqus = angio_get_option( 'disqus_comments', 'off' );
				if ( ( $disqus && $disqus === 'on' ) ) {
					if ( function_exists( 'angio_toolkit_disqus' ) ) {
						echo angio_toolkit_disqus( get_the_ID() );
					}
					
				} else {
					comments_template();
				}
				?>
		</div>
		<?php endif; ?>
	<?php endif; ?>
</div> <!-- .content -->


<?php
/////////////
// SIDEBAR //
/////////////
get_sidebar( 'custom', ['position' => $sidebar_pos ] );