<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            content-fullscreen.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( null === get_query_var( 'angio_vars' ) ) {
	return;
}

///////////////////////
// CONTENT VARIABLES //
///////////////////////
$space_start = '300';
$space_end = '300';
$fs_fx = get_post_meta( get_the_ID(), '_fs_fx', true ); 
$fs_fx = ( ! isset( $fs_fx ) || $fs_fx === '' ) ? 'image' : $fs_fx;

$fade_layer = get_post_meta( get_the_ID(), '_fade_layer', true ); 
$fade_layer = ( ! isset( $fade_layer ) || $fade_layer === '' ) ? '0' : $fade_layer;


/////////////
// SIDEBAR //
/////////////
$sidebar_pos = get_post_meta( get_the_ID(), '_sidebar_position', true ); 
$sidebar_pos = ( ! isset( $sidebar_pos ) || $sidebar_pos === '' ) ? angio_get_option( 'album_def_sidebar_pos', 'disabled' ) : $sidebar_pos;


////////////
// LAYOUT //
////////////
$page_layout = get_post_meta( get_the_ID(), '_page', true );
$page_layout = $page_layout === 'fullscreen' ? 'fs-scroll--v' : 'fs-scroll--h';

if ( $page_layout === 'fs-scroll--v') {
	$content_classes = array(
		'content--fullscreen', 
		'content--builder' 
	);
} else {
	$content_classes = array(
		'content--horizontal'
	);
}

$content = get_post_meta( get_the_ID(), '_content', true );
$content = ( $content !== '' ? $content : 'default' );

$container_classes = array(
	'container'
);

if ( $content === 'default' ) {
	array_push( $content_classes, 'content--layout-default' );
	$container_classes[] = 'container--narrow';
} else if ( $content === 'fullwidth' ) {
	unset( $container_classes );
	$container_classes[] = 'container--full';
} else if ( $content === 'elementor' ) {
	unset( $container_classes, $content_classes );
	$content_classes[] = 'content--builder';
	$container_classes[] = 'container--builder';
}
if ( get_post_meta( get_the_ID(), '_content_space', true ) ) {
	$content_space = get_post_meta( get_the_ID(), '_content_space', true );
	$space_start = $content_space['start'];
	$space_end = $content_space['end'];
}


///////////
// IMAGE //
///////////
if ( ! empty( get_post_meta( get_the_ID(), '_image_bg', true ) ) ) {
	$image_bg = get_post_meta( get_the_ID(), '_image_bg', true ); 
    $image_id = $image_bg;
    $img_src_full = wp_get_attachment_image_src( $image_id, 'full' );
    $img_src_full = $img_src_full[0];
    $img_src_large = wp_get_attachment_image_src( $image_id, 'large' );
	$img_src_large = $img_src_large[0];
} else {
   $img_src_full = false;
   $img_src_large = false;
}


////////////////////
// PAGE VARIABLES //
////////////////////
$opts = get_query_var( 'angio_vars' );
$sidebar_pos = (isset($opts['sidebar_pos'])) ? $opts['sidebar_pos'] : $sidebar_pos;
$page_title = (isset($opts['page_title'])) ? $opts['page_title'] : $page_title;
$space_start = (isset($opts['space_start'])) ? $opts['space_start'] : $space_start;
$space_end = (isset($opts['space_end'])) ? $opts['space_end'] : $space_end;


// Clear space start if page title set
if ( $page_title !== 'disabled' ) {
	$space_start = 0;
}

//////////
// LOOP //
//////////
$temp_post = $post;
$query_temp = $wp_query;

$wp_query = new WP_Query();
$wp_query->query( $opts['query_args'] );

?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>">
<?php 

	///////////////
	// GLITCH FX //
	///////////////

	if ( $fs_fx === 'glitch-image' && $img_src_full ) : ?>
		
		<div id="fx-wgl-glitch" class="fs" data-image-src="<?php echo esc_attr($img_src_full) ?>">
			
			<canvas id="fx-wgl-glitch-canvas"></canvas>

			<div class="fs__image" style="background-image: url(<?php echo esc_attr($img_src_full) ?>)"></div>

	<?php 

	////////////////////
	// PERSPECTIVE FX //
	////////////////////

	elseif ( $fs_fx === 'perspective-image' && $img_src_full ) : ?>

		<div class="fx-perspective fs">

			<div class="fs__image fx-perspective__image" style="background-image: url(<?php echo esc_attr($img_src_full) ?>)"></div>

	<?php

	////////////////////
	// SMOOTH MOVE FX //
	////////////////////

	elseif ( $fs_fx === 'smooth-move' && $img_src_full ) : ?>
	
		<div class="fx-smooth-move fs">
			<div class="fs__image fx-smooth-move-bg fx-smooth-move-layer" style="background-image: url(<?php echo esc_attr($img_src_full) ?>)"></div>

	<?php

	///////////
	// IMAGE //
	///////////

	elseif ( $fs_fx === 'image' && $img_src_full ) : ?>
	
		<div class="fx-image fs">
			<div class="fs__image" style="background-image: url(<?php echo esc_attr($img_src_full) ?>)"></div>

	<?php

	///////////
	// NO FX //
	///////////
	else : ?>
		<div class="no-fx fs">
	<?php endif; ?>

	<?php
	////////////
	// COMMON //
	////////////
	
	?>
			<div class="fade-layer" style="opacity:<?php echo esc_attr($fade_layer) ?>"></div>

			<?php 
			/////////////
			// VERICAL //
			/////////////

			if ( $page_layout === 'fs-scroll--v') : ?>

				<div id="fs-scroll" class="fs-scroll--v">
					<?php
					if ( have_posts() ) : ?>
						<?php
						// Set Query VARS
						set_query_var( 'angio_vars', $opts );
						get_template_part( 'partials/title', $page_title);
						?>
						<div id="fs-scroll__content">
							<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>" style="padding-top:<?php echo esc_attr( $space_start ) ?>px;padding-bottom:<?php echo esc_attr( $space_end ) ?>px">
								<?php 
								////////////
								// RENDER //
								////////////
								get_template_part( 'partials/loop', $opts['block'] );
								angio_paging_nav(); 
								?>
							</div>
						</div> <!-- #fs-scroll__content -->
					<?php endif; // have_posts() ?>
				</div><!-- #fs-scroll -->

			<?php 
			////////////////
			// HORIZONTAL //
			////////////////

			else : ?>
				<div id="fs-scroll" class="fs-scroll--h">
				<?php
				if ( have_posts() ) : ?>
					<div id="fs-scroll__content">

						<?php 
						////////////
						// RENDER //
						////////////
						set_query_var( 'angio_vars', $opts );
						get_template_part( 'partials/loop', $opts['block'] );
						angio_paging_nav(); 
						?>

					</div> <!-- #fs-scroll__content -->
				<?php endif; // have_posts() ?>
				</div><!-- #fs-scroll -->

			<?php endif; ?>

		</div> <!-- .fx -->

</div> <!-- .content -->

<?php 
// Restore query 
$post = $temp_post;
$wp_query = $query_temp;
?>

<?php
/////////////
// SIDEBAR //
/////////////
get_sidebar( 'custom', ['position' => $sidebar_pos ] );