<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            loop.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
if ( null === get_query_var( 'angio_vars' ) ) {
	return;
}


///////////////////////
// CONTENT VARIABLES //
///////////////////////
$page_title = 'empty';


////////////
// LAYOUT //
////////////
$content = get_post_meta( get_the_ID(), '_content', true );
$content = ( $content !== '' ? $content : angio_get_option( 'post_def_layout', 'default' ) );
$content_classes = array(
	'content'
);
$container_classes = array(
	'container'
);
if ( $content === 'default' ) {
	array_push( $content_classes, 'content--layout-default' );
	$container_classes[] = 'container--narrow';
} else if ( $content === 'fullwidth' ) {
	unset( $container_classes );
	$container_classes[] = 'container--full';
} else if ( $content === 'elementor' ) {
	unset( $container_classes, $content_classes );
	$content_classes[] = 'content--builder';
	$container_classes[] = 'container--builder';
}


/////////////
// SIDEBAR //
/////////////
$sidebar_pos = get_post_meta( get_the_ID(), '_sidebar_position', true ); 
$sidebar_pos = ( ! isset( $sidebar_pos ) || $sidebar_pos === '' ) ? angio_get_option( 'album_def_sidebar_pos', 'disabled' ) : $sidebar_pos;


////////////////////
// PAGE VARIABLES //
////////////////////
$opts = get_query_var( 'angio_vars' );
$content_classes = (isset($opts['content_classes'])) ? $opts['content_classes'] : $content_classes;
$container_classes = (isset($opts['container_classes'])) ? $opts['container_classes'] : $container_classes;
$page_title =  (isset($opts['page_title'])) ? $opts['page_title'] : $page_title;
$sidebar_pos =  (isset($opts['sidebar_pos'])) ? $opts['sidebar_pos'] : $sidebar_pos;


////////////////
// BACKGROUND //
////////////////
if ( ! empty( get_post_meta( get_the_ID(), '_image_vertical_bg', true ) ) ) {
	$image_bg = get_post_meta( get_the_ID(), '_image_vertical_bg', true ); 
    $image_id = $image_bg;
    $img_src_full = wp_get_attachment_image_src( $image_id, 'full' );
    $img_src_full = $img_src_full[0];
    $img_src_large = wp_get_attachment_image_src( $image_id, 'large' );
	$img_src_large = $img_src_large[0];
	
	$bg_style = get_post_meta( get_the_ID(), '_vertical_bg_style', true );
	$bg_style = (!empty($bg_style)) ? $bg_style : 'fixed';
} else {
	$image_bg = false;
	$img_src_full = false;
	$img_src_large = false;
	$bg_style = 'none';
}


////////////////////////
// CONTENT BACKGROUND //
////////////////////////
if ( $image_bg && $bg_style === 'fixed' ) : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>" data-app-bg="<?php echo esc_attr($img_src_full ) ?>">
<?php elseif ( $image_bg && $bg_style === 'scroll' ) : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?> content-bg" style="background-image:url(<?php echo esc_attr($img_src_full ) ?>)">
<?php else : ?>
<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>">
<?php endif; ?>


<?php 

///////////
// TITLE //
///////////
get_template_part( 'partials/title', $page_title);

 ?>

	<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>">

		<?php 

			//////////
			// LOOP //
			//////////

			// Copy query 
			$temp_post = $post;
			$query_temp = $wp_query;
			
			// Custom Loop
			if ( isset( $opts['query_args'] ) ) {
			 	$wp_query = new WP_Query();
				$wp_query->query( $opts['query_args'] );
			}
           

			if ( have_posts() ) : ?>

				<?php
				////////////////
				// LOOP BLOCK //
				////////////////
				set_query_var( 'angio_vars', $opts );
				get_template_part( 'partials/loop', $opts['block'] );
				

				////////////////
				// PAGINATION //
				////////////////
				angio_paging_nav(); 
				?>

			<?php else : ?>
				<p><?php esc_html_e( 'It seems we can not find what you are looking for.', 'angio' ); ?></p>
			<?php endif; // have_posts() ?>
		
			<?php 
			// Restore query 
			$post = $temp_post;
			$wp_query = $query_temp;
		?>


    </div> <!-- .container -->

</div> <!-- .content -->


<?php
/////////////
// SIDEBAR //
/////////////
get_sidebar( 'custom', ['position' => $sidebar_pos ] );