<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            title-fullscreen-parallax.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Get custom vars 
$opts = get_query_var( 'angio_vars' );

// Classes
$pt_classes = array('pt', 'pt-fs-image');
$pt_inner_classes = array( 'pt-fs-image__inner', 'is-waypoint' );

// Container
$container_classes = array('container', 'container--narrow');
if (isset($opts['container_classes']) ) {
	$container_classes = $opts['container_classes'];
}

// Post type
$post_type = get_post_type( get_the_ID() );


// Custom Title
if (isset($opts['custom_title']) && $opts['custom_title'] !== '') {
	$title = $opts['custom_title'];
} else {
	$title = get_the_title( get_the_ID() );
}

// Show image?
$show_image = true;
if (isset($opts['show_image']) && $opts['show_image'] === false ) {
	$show_image = false;
} 

// Get featured image
$title_image = get_post_meta( get_the_ID(), '_title_image', true ); 

if ( $title_image ) {
	$pt_classes[] = 'pt--is-image';
    $image_id = $title_image;
    $img_src_full = wp_get_attachment_image_src( $image_id, 'full' );
    $img_src_full = $img_src_full[0];
    $img_src_large = wp_get_attachment_image_src( $image_id, 'large' );
	$img_src_large = $img_src_large[0];
} else if ( angio_get_post_image( get_the_ID(), 'full' ) ) {
	$pt_classes[] = 'pt--is-image';
    $img_src_full = angio_get_post_image( get_the_ID(), 'full' );
    $img_src_large = angio_get_post_image( get_the_ID(), 'large' );
} else {
    $img_src_full = false;
    $img_src_large = false;
}

// Effects
$pt_classes[] = 'hide-header';

?>
<div class="<?php echo esc_attr( implode(' ', $pt_classes ) ) ?>" >
	<div class="pt-image-bg fx-parallax-scroll" data-duration="100%" data-trigger-hook="0" data-offset="0" style="background-image: url(<?php echo esc_attr( $img_src_full ) ?>)" data-anim-obj='{"duration": "1", "scale":"1.1", "opacity":"0.8", "ease":"Linear.easeNone"}'></div>
	<div class="<?php echo esc_attr( implode(' ', $pt_inner_classes ) ) ?>">
		<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>">
			<div class="fx-parallax-scroll" data-duration="60%" data-trigger-hook="0.4" data-anim-obj='{"duration": "0.5", "yPercent":"30", "opacity":"0", "ease":"Linear.easeNone"}'>
				<?php if ( $post_type === 'post') : ?>
					<div class="pt-meta meta">
						<?php get_template_part( 'partials/meta', 'date' ); ?>
					</div>
				<?php endif; ?>
				<?php get_template_part( 'partials/meta', 'title' ); ?>
				<?php if ( $post_type === 'post') : ?>
					<div class="pt-meta meta">
						<?php get_template_part( 'partials/meta', 'categories' ); ?>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>
</div>