<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            title-image.php
 * @package angio
 * @since 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Get custom vars 
$opts = get_query_var( 'angio_vars' );

// Classes
$pt_classes = array('pt', 'pt-image');

// Container
$container_classes = array('container', 'container--narrow');

if (isset($opts['container_classes']) ) {
	$container_classes = $opts['container_classes'];
} 

// Post type
$post_type = get_post_type( get_the_ID() );

if (isset($opts['custom_title']) && $opts['custom_title'] !== '') {
	$title = $opts['custom_title'];
} else {
	$title = get_the_title( get_the_ID() );
}
// Get featured image
if ( ! empty( get_post_meta( get_the_ID(), '_title_image', true ) ) ) {
	$pt_classes[] = 'pt--is-image';
    $image_id = get_post_meta( get_the_ID(), '_title_image', true );
    $img_src_full = wp_get_attachment_image_src( $image_id, 'full' );
    $img_src_full = isset( $img_src_full[0] ) ? $img_src_full[0] : false;
    $img_src_large = wp_get_attachment_image_src( $image_id, 'large' );
	$img_src_large = isset( $img_src_large[0] ) ? $img_src_large[0] : false;
} else if ( angio_get_post_image( get_the_ID(), 'full' ) ) {
	$pt_classes[] = 'pt--is-image';
    $img_src_full = angio_get_post_image( get_the_ID(), 'full' );
    $img_src_large = angio_get_post_image( get_the_ID(), 'large' );
} else {
    $img_src_full = false;
    $img_src_large = false;
}

?>
<div class="<?php echo esc_attr( implode(' ', $pt_classes ) ) ?>">

	<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>">
		<div class="fx-parallax-scroll" data-duration="200" data-trigger-hook="0">
		<?php if ( $post_type === 'post') : ?>
			<div class="pt-meta meta">
				<?php get_template_part( 'partials/meta', 'date' ); ?>
			</div>
		<?php endif; ?>
		
		<?php get_template_part( 'partials/meta', 'title' ); ?>
		<?php if ( $post_type === 'post') : ?>
			<div class="pt-meta meta">
				<?php get_template_part( 'partials/meta', 'categories' ); ?>
			</div>
		<?php endif; ?>
		</div>
	</div>

	<?php if ( $img_src_full ) : ?>

		<?php 
		// Show image container wide on small "default" content container 
		if ( in_array('container--full', $container_classes ) ) : ?>
			<div class="<?php echo esc_attr( implode(' ', $container_classes ) ) ?>">
		<?php else : ?>
			<div class="container container--wide">
		<?php endif; ?>


		<div class="pt__featured">
			<div class="fx-scale fx-scale is-waypoint">
				<div class="img">
					<div class="fx-parallax-scroll" data-duration="70%" data-trigger-hook="0" data-anim-obj='{"duration": "1", "yPercent":"15", "opacity":"0", "scale":"0.9", "ease":"Linear.easeNone"}'>
						<picture>
							<source media="(max-width:768px)" srcset="<?php echo esc_url( $img_src_large ) ?>">
							<img src="<?php echo esc_url( $img_src_full ) ?>" alt="<?php esc_attr_e( 'Post Image', 'angio' ) ?>">
						</picture>
					</div>
				</div>
			</div>
		</div>
	</div>
	<?php endif; ?>
</div>