<?php
/**
 * Theme Name:      Angio
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/theme/angio
 * Author URI:      http://rascalsthemes.com
 * File:            single-angio_events.php
 * @package angio
 * @since 1.0.0
 */

get_header();

///////////////////////
// CONTENT VARIABLES //
///////////////////////
$page = get_post_meta( get_the_ID(), '_page', true );
$page = ( $page !== '' ? $page : angio_get_option( 'event_def_page_layout', 'default' ) );

// Album Layout
$event_layout = get_post_meta( get_the_ID(), '_event_layout', true );
$event_layout = ( $event_layout !== '' ? $event_layout : angio_get_option( 'event_def_event_layout', 'event1' ) );

// Content layout
$content = get_post_meta( get_the_ID(), '_content', true );
$content = ( $content !== '' ? $content : angio_get_option( 'event_def_content', 'default' ) );

// Title
$page_title = get_post_meta( get_the_ID(), '_page_title', true );
$page_title = ( $page_title !== '' ? $page_title : angio_get_option( 'event_def_page_title', 'simple' ) );


////////////
// LAYOUT //
////////////
$container_classes = array('container', 'container--narrow');
if ( $content === 'wide') {
	$container_classes = array('container');
} else if ( $content === 'fullwidth') {
	$container_classes = array('container', 'container--full');
} else if ( $content === 'elementor' ) {
	$container_classes = array('container--builder');
}


//////////////////////
// CUSTOM VARIABLES //
//////////////////////
$custom_vars = array(
	'page_title' => $page_title,
	'container_classes' => $container_classes,
	'show_content_footer' => false,
);

if ( in_array( $event_layout, ['custom-clear'], true )) {
	$custom_vars = array( 
		'page_title'          => $page_title,
		'container_classes'   => $container_classes,
		'show_content_footer' => false,
		'show_nav'            => false,
		'show_comments'       => false,
	);

}
if ( in_array( $event_layout, ['event1'], true )) {
	$custom_vars = array( 
		'page_title'          => 'none',
		'render'              => 'event',
		'space_start'         => '0',
		'space_end'           => '150',
		'show_content_footer' => false,
		'show_nav'            => false,
		'show_comments'       => false,
		'content_classes'     => array( 'content--event' ),
		'container_classes'   => array( 'container')
	);
}

set_query_var( 'angio_vars', $custom_vars );


//////////////
// BG MUSIC //
//////////////
if ( function_exists( 'angio_toolkit_get_audio' ) && angio_get_option( 'background_player', 'off' ) === 'on' ) {
	$track_id = get_post_meta( get_the_ID(), '_track_id', true );
	$track_ids = get_post_meta( get_the_ID(), '_tracks_ids', true );
    $tracks = angio_toolkit_get_audio( $track_id, $track_ids );

    if ( $tracks ) {
    	echo '<div class="rp-page-audio" data-audio="' . esc_url( $tracks[0]['url'] ) . '"></div>';
    }

}


/////////////
// CONTENT //
/////////////

// Fullscreen
if ( $page === 'fullscreen' ) {
	get_template_part( 'partials/content', 'fullscreen' ); 
}

// Vertical Scroll
if ( $page === 'default' ) {

	if ( in_array( $content, ['default','wide','fullwidth','elementor'], true ) ) {
		
		// Default
		get_template_part( 'partials/content', '' ); 

	} 
}
 

////////////
// FOOTER //
////////////
get_footer();