<?php
/**
 * Template Name: FullScreen Menu
 *
 * @package angio
 * @since 1.0.0
 */

get_header();

// BG Type
$fs_fx = get_post_meta( get_the_ID(), '_fs_fx', true ); 
$fs_fx = ( ! isset( $fs_fx ) || $fs_fx === '' ) ? 'image' : $fs_fx;

// Fade layer
$fade_layer = get_post_meta( get_the_ID(), '_fade_layer', true ); 
$fade_layer = ( ! isset( $fade_layer ) || $fade_layer === '' ) ? '0' : $fade_layer;

// Position
$position = get_post_meta( get_the_ID(), '_position', true ); 
$position = ( ! isset( $position ) || $position === '' ) ? 'center-bottom' : $position;

// Sidebar
$sidebar_pos = get_post_meta( get_the_ID(), '_sidebar_position', true ); 
$sidebar_pos = ( ! isset( $sidebar_pos ) || $sidebar_pos === '' ) ? angio_get_option( 'gallery_def_sidebar_pos', 'disabled' ) : $sidebar_pos;

$content_classes = array(
	'content--fullscreen', 
	'content--builder',
	'content--menu-layer'
);

$content_classes[] = $position;

// Image BG
$image_bg = get_post_meta( get_the_ID(), '_image_bg', true ); 

// IMAGE SRC
if ( $image_bg ) {
    $image_id = $image_bg;
    $image_bg_src = wp_get_attachment_image_src( $image_id, 'full' );
    $image_bg_src = $image_bg_src[0];
} else {
   $image_bg_src = false;
}

// Layer image
$layer_image = get_post_meta( get_the_ID(), '_layer_image', true ); 
if ( $layer_image ) {
    $image_id = $layer_image;
    $layer_img_src = wp_get_attachment_image_src( $image_id, 'full' );
    $layer_img_src = $layer_img_src[0];
} else {
   $layer_img_src = false;
}


//////////////
// BG MUSIC //
//////////////
if ( function_exists( 'angio_toolkit_get_audio' ) && angio_get_option( 'background_player', 'off' ) === 'on' ) {
	$track_id = get_post_meta( get_the_ID(), '_track_id', true );
	$track_ids = get_post_meta( get_the_ID(), '_tracks_ids', true );
    $tracks = angio_toolkit_get_audio( $track_id, $track_ids );

    if ( $tracks ) {
    	echo '<div class="rt-player-audio" data-audio="' . esc_url( $tracks[0]['url'] ) . '"></div>';
    }

}
?>

<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>">

<?php 

    ///////////////
    // GLITCH FX //
    ///////////////

    if ( $fs_fx === 'glitch-image' && $image_bg_src ) : ?>
        
        <div id="fx-wgl-glitch" class="fs" data-image-src="<?php echo esc_attr($image_bg_src) ?>">
            
            <canvas id="fx-wgl-glitch-canvas"></canvas>

            <div class="fs__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php 

    ////////////////////
    // PERSPECTIVE FX //
    ////////////////////

    elseif ( $fs_fx === 'perspective-image' && $image_bg_src ) : ?>

        <div class="fx-perspective fs">

            <div class="fs__image fx-perspective__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php

    ////////////////////
    // SMOOTH MOVE FX //
    ////////////////////

    elseif ( $fs_fx === 'smooth-move' && $image_bg_src ) : ?>
    
        <div class="fx-smooth-move fs">
            <div class="fs__image fx-smooth-move-bg fx-smooth-move-layer" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php

    ///////////
    // IMAGE //
    ///////////

    elseif ( $fs_fx === 'image' && $image_bg_src ) : ?>
    
        <div class="fx-image fs">
            <div class="fs__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>


    <?php

    ///////////
    // NO FX //
    ///////////
    else : ?>
        <div class="no-fx fs">
    <?php endif; ?>

    <?php
    ////////////
    // COMMON //
    ////////////

    ?>
        <div class="fade-layer" style="opacity:<?php echo esc_attr($fade_layer) ?>"></div>
        <?php if ( $layer_img_src ) : ?>

            <div class="fx-smooth-move-layer artist-layer" data-move-x="60" data-move-y="60">
                <div class="img fx-slow-move-from-bottom">
                    <img src="<?php echo esc_url($layer_img_src) ?>" alt="<?php esc_attr_e( 'Layer Image', 'angio') ?>">
                </div>
            </div>

        <?php endif; ?>

        <?php 

        /////////////////
        // CUSTOM MENU //
        /////////////////

        $custom_menu = get_post_meta( get_the_ID(), '_custom_menu', true ); 
        $custom_menu = ( ! isset( $custom_menu ) || $custom_menu === 'disabled' ) ? false : intval($custom_menu);

        
        if ( $custom_menu ) : 
                $custom_menu_args = array(
                    'menu'            => $custom_menu,
                    'container'       => false,
                    'container_class' => '',
                    'menu_class'      => 'custom-menu__nav',
                    'depth'           => 1
                ); 
            ?>

            <div class="custom-menu fx-smooth-move-layer js-create-b-style-3" data-move-x="20" data-move-y="20">
                <?php wp_nav_menu($custom_menu_args ); ?>
            </div>
        <?php endif; ?>


    </div> <!-- .fx -->

</div> <!-- .content -->


<?php
/////////////
// SIDEBAR //
/////////////
get_sidebar( 'custom', ['position' => $sidebar_pos ] );


// Get footer
get_footer();