<?php
/**
 * Template Name: Magic Wave
 *
 * @package angio
 * @since 1.0.0
 */

get_header();

// BG Type
$fs_fx = get_post_meta( get_the_ID(), '_fs_fx', true ); 
$fs_fx = ( ! isset( $fs_fx ) || $fs_fx === '' ) ? 'image' : $fs_fx;

// Fade layer
$fade_layer = get_post_meta( get_the_ID(), '_fade_layer', true ); 
$fade_layer = ( ! isset( $fade_layer ) || $fade_layer === '' ) ? '0' : $fade_layer;

// Sidebar
$sidebar_pos = get_post_meta( get_the_ID(), '_sidebar_position', true ); 
$sidebar_pos = ( ! isset( $sidebar_pos ) || $sidebar_pos === '' ) ? angio_get_option( 'page_def_sidebar_pos', 'disabled' ) : $sidebar_pos;

$content_classes = array(
	'content--fullscreen', 
	'content--builder',
	'content--parallax-layers'
);


// Image BG
$image_bg = get_post_meta( get_the_ID(), '_image_bg', true ); 

// IMAGE SRC
if ( $image_bg ) {
    $image_id = $image_bg;
    $image_bg_src = wp_get_attachment_image_src( $image_id, 'full' );
    $image_bg_src = $image_bg_src[0];
} else {
   $image_bg_src = false;
}


//////////////
// BG MUSIC //
//////////////
if ( function_exists( 'angio_toolkit_get_audio' ) && angio_get_option( 'background_player', 'off' ) === 'on' ) {
	$track_id = get_post_meta( get_the_ID(), '_track_id', true );
	$track_ids = get_post_meta( get_the_ID(), '_tracks_ids', true );
    $tracks = angio_toolkit_get_audio( $track_id, $track_ids );

    if ( $tracks ) {
    	echo '<div class="rp-page-audio" data-audio="' . esc_url( $tracks[0]['url'] ) . '"></div>';
    }

}
?>

<div class="<?php echo esc_attr( implode(' ', $content_classes ) ) ?>">

<?php 

    ///////////////
    // GLITCH FX //
    ///////////////

    if ( $fs_fx === 'glitch-image' && $image_bg_src ) : ?>
        
        <div id="fx-wgl-glitch" class="fs" data-image-src="<?php echo esc_attr($image_bg_src) ?>">
            
            <canvas id="fx-wgl-glitch-canvas"></canvas>

            <div class="fs__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php 

    ////////////////////
    // PERSPECTIVE FX //
    ////////////////////

    elseif ( $fs_fx === 'perspective-image' && $image_bg_src ) : ?>

        <div class="fx-perspective fs">

            <div class="fs__image fx-perspective__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php

    ////////////////////
    // SMOOTH MOVE FX //
    ////////////////////

    elseif ( $fs_fx === 'smooth-move' && $image_bg_src ) : ?>
    
        <div class="fx-smooth-move fs">
            <div class="fs__image fx-smooth-move-bg fx-smooth-move-layer" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>

    <?php

    ///////////
    // IMAGE //
    ///////////

    elseif ( $fs_fx === 'image' && $image_bg_src ) : ?>
    
        <div class="fx-image fs">
            <div class="fs__image" style="background-image: url(<?php echo esc_attr($image_bg_src) ?>)"></div>
    <?php

    ///////////
    // NO FX //
    ///////////
    else : ?>
        <div class="no-fx fs">
    <?php endif; ?>

    <?php
    ////////////
    // COMMON //
    ////////////
    ?>

    	<?php 
    	$color_one = get_post_meta( get_the_ID(), '_wave_color1', true );
    	$color_one = (!empty($color_one)) ? $color_one : '#33f7dd';
    	$color_two = get_post_meta( get_the_ID(), '_wave_color2', true );
    	$color_two = (!empty($color_two)) ? $color_two : '#13776a';

	 	?>
    	<canvas id="magic-wave" data-col1="<?php echo esc_attr($color_one) ?>" data-col2="<?php echo esc_attr($color_two) ?>"></canvas>

        <?php 
        $latest_album = get_post_meta( get_the_ID(), '_latest_album', true );
        $promo_buttons = get_post_meta( get_the_ID(), '_promo_buttons', true );

        if ( $latest_album && $latest_album !== 'none' )  : ?>

        	<div class="wave-album">
        		<div class="wave-move-this">
        			
	           	<?php 

	           	if ( function_exists( 'angio_album_module1' ) ) {
				    echo angio_album_module1( array(
						'post_id'       => $latest_album,
						'classes'       => 'wave-album__mod',
				    ) );
				}

	            ?>
		            <div class="wave-album__desc">
		            	<?php 
	            			$wave_text = get_post_meta( get_the_ID(), '_wave_text', true );
	            			$wave_text = (!empty($wave_text)) ? $wave_text : esc_html__( 'New album out now', 'angio' );
	            			echo angio_theme_title([
								'el' => 'h1',
								'title' => $wave_text,
								'effect' => 'console_typer',
								'data' => [
									'timer' => '1500'
								],
								'classes' => 'wave-album__text waypoint-pause',
							]);
	            	 	?>

		            	<?php 

		            	// Buttons IDs

					    if ( !empty( $promo_buttons ) ) : ?>

					        <div class="wave-album__buttons is-waypoint waypoint-pause anim-stagger" data-timer="2000" data-stagger='{"duration":0.3, "opacity":1, "y":0, "ease": "power3.out"}'>

					        <?php
					        $promo_buttons_a = explode( '|', $promo_buttons ); 

					        foreach ($promo_buttons_a as $key => $id) :

					            // Get data
					            $data = get_post_meta( get_the_ID(), '_promo_buttons_' . $id, true );

					            // Add default values 
					            $defaults = array(
					                'title' => '',
					                'icon'  => 'facebook',
					                'link'  => '#',
					             );

					            if ( isset( $data ) && is_array( $data ) ) {
					                $data = array_merge( $defaults, $data );
					            } else {
					                $data = $defaults;
					            }
					            ?>
					            <a href="<?php echo esc_url($data['link']) ?>" class="promo-button stagger-item"><span class="promo-button__icon icon icon-<?php echo esc_attr($data['icon']) ?>"></span></a>
					      
					      	<?php endforeach; ?>
					        </div>
					    
					    <?php endif ?>

		            </div>
	            </div>

            </div>
        <?php endif; ?>


    </div> <!-- .fx -->

</div> <!-- .content -->


<?php
/////////////
// SIDEBAR //
/////////////
get_sidebar( 'custom', ['position' => $sidebar_pos ] );


// Get footer
get_footer();